function [residual, g1, g2] = cimpr1_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 357, 1);

%
% Model equations
%

T3 = (-1);
T25 = (y(3)-y(3)*params(50))^params(5)*(1-params(36)*y(4))^(1-params(5));
T28 = T25^(-params(2));
T32 = ((1-params(36)*y(4))/(y(3)-y(3)*params(50)))^(1-params(5));
T35 = (y(3)-y(3)*params(50))/(1-params(50));
T41 = T35-params(36)*y(4)^(1+params(35))/(1+params(35));
T59 = (y(50)-params(50)*y(50))^params(5)*(1-params(36)*y(51))^(1-params(5));
T60 = T59^(-params(2));
T64 = ((1-params(36)*y(51))/(y(50)-params(50)*y(50)))^(1-params(5));
T66 = (y(50)-params(50)*y(50))/(1-params(50));
T70 = T66-params(36)*y(51)^(1+params(35))/(1+params(35));
T82 = ((y(3)-y(3)*params(50))/(1-params(36)*y(4)))^params(5);
T98 = ((y(50)-params(50)*y(50))/(1-params(36)*y(51)))^params(5);
T112 = y(2)*params(1)/y(2);
T124 = y(49)*params(1)/y(49);
T129 = y(8)*T124/y(13)*y(123)/y(123);
T141 = y(123)*T112*y(55)/y(60)/y(123);
T206 = y(103)/y(15)*exp(y(105));
T210 = params(13)*T206^(-params(4));
T221 = y(104)/y(62)*exp(y(106));
T223 = params(14)*T221^(-params(4));
T233 = y(117)/y(15)*exp(y(119));
T235 = params(15)*T233^(-params(4));
T244 = y(118)/y(62)*exp(y(120));
T246 = params(16)*T244^(-params(4));
T255 = y(103)/y(14)*exp(y(107));
T257 = params(17)*T255^(-params(4));
T267 = y(104)/y(61)*exp(y(108));
T269 = params(18)*T267^(-params(4));
T278 = y(117)/y(14)*exp(y(121));
T280 = params(19)*T278^(-params(4));
T288 = y(118)/y(61)*exp(y(122));
T290 = params(20)*T288^(-params(4));
T299 = (params(38)-1)/params(38);
T304 = y(2)*params(1)*params(37)/y(2);
T317 = y(49)*params(1)*params(37)/y(49);
T361 = params(13)*(y(103)*exp(y(105)))^(1-params(4))+params(15)*(y(117)*exp(y(119)))^(1-params(4));
T362 = 1/(1-params(4));
T371 = params(14)*(y(104)*exp(y(106)))^(1-params(4))+params(16)*(y(118)*exp(y(120)))^(1-params(4));
T380 = params(17)*(y(103)*exp(y(107)))^(1-params(4))+params(19)*(y(117)*exp(y(121)))^(1-params(4));
T389 = params(18)*(y(104)*exp(y(108)))^(1-params(4))+params(20)*(y(118)*exp(y(122)))^(1-params(4));
T392 = 1/params(1);
T396 = T392*(y(8)/T392)^params(39);
T401 = y(13)^params(40)*y(13)^params(41);
T403 = T401^(1-params(39));
T408 = T392*(y(55)/T392)^params(39);
T411 = y(60)^params(40)*y(60)^params(41);
T412 = T411^(1-params(39));
T424 = y(29)^(params(3)*(-params(22)));
T425 = 1/y(123);
T427 = T425^(-params(3));
T430 = T424*T427*y(104)^params(3);
T432 = T430*y(102);
T443 = params(6)/params(45)*(params(3)-1)/params(3);
T445 = T443/y(9);
T448 = T445^(params(46)-1);
T451 = 1-params(12);
T453 = y(34)^(params(46)*T451);
T458 = y(25)*params(3)/(params(3)-1)/(1-params(6));
T463 = T458^(params(46)+params(46)*(-params(3))*params(12)-1);
T467 = y(22)^(params(46)*params(12));
T470 = y(21)^(params(46)*params(12));
T472 = y(40)*T467+y(42)*T470;
T477 = y(35)^(params(46)*T451);
T484 = T467*y(41)+T470*y(43);
T492 = y(76)^(params(3)*(-params(22)));
T494 = T492*y(123)^(-params(3));
T496 = T494*y(117)^params(3);
T505 = T443/y(56);
T506 = T505^(params(46)-1);
T508 = y(81)^(params(46)*T451);
T511 = y(72)*params(3)/(params(3)-1)/(1-params(6));
T512 = T511^(params(46)+params(46)*(-params(3))*params(12)-1);
T515 = y(69)^(params(46)*params(12));
T518 = y(68)^(params(46)*params(12));
T520 = y(87)*T515+y(89)*T518;
T525 = y(82)^(params(46)*T451);
T532 = T515*y(88)+T518*y(90);
T535 = params(6)/(1-params(6));
T574 = params(45)*params(53)/params(44);
T575 = T445^params(46);
T580 = T458^(params(46)*(1-params(3)*params(12)));
T592 = T505^params(46);
T594 = T511^(params(46)*(1-params(3)*params(12)));
T618 = 1-(1-params(6))*(params(3)-1)/params(3);
T620 = params(3)/(params(3)-1)/(1-params(6));
T622 = (y(25)*T620)^(1-params(3)*params(12));
T624 = y(34)^T451;
T625 = exp(y(30))^((params(3)-1)*params(12))*T618*T622*T624;
T628 = y(21)^params(12);
T632 = y(22)^params(12);
T634 = y(17)^T451*T628-y(18)^T451*T632;
T650 = y(35)^T451;
T651 = T622*T618*exp(y(31))^((params(3)-1)*params(12))*T650;
T658 = T628*y(19)^T451-T632*y(20)^T451;
T672 = (y(72)*T620)^(1-params(3)*params(12));
T674 = y(81)^T451;
T675 = T618*exp(y(77))^((params(3)-1)*params(12))*T672*T674;
T678 = y(68)^params(12);
T682 = y(69)^params(12);
T684 = y(64)^T451*T678-y(65)^T451*T682;
T699 = y(82)^T451;
T700 = T672*T618*exp(y(78))^((params(3)-1)*params(12))*T699;
T707 = T678*y(66)^T451-T682*y(67)^T451;
T717 = params(6)*params(53)/(1-params(6));
T718 = y(25)*T717;
T722 = (params(3)-1)^params(12);
T723 = exp(y(30))^(T722);
T725 = (y(25)*T620)^((-params(3))*params(12));
T745 = exp(y(31))^(T722);
T765 = y(72)*T717;
T769 = exp(y(77))^(T722);
T771 = (y(72)*T620)^((-params(3))*params(12));
T791 = exp(y(78))^(T722);
T895 = y(29)^(params(3)*params(22));
T900 = T448*T580*y(22)^(params(46)*params(12)-1);
T912 = T425^(1-params(3));
T914 = y(21)^(params(46)*params(12)-1);
T915 = T424*T580*T912*T914;
T924 = (y(117)/y(123))^(1-params(3));
T925 = y(76)^(params(3)*params(22));
T929 = T506*T594*y(69)^(params(46)*params(12)-1);
T941 = y(123)^(1-params(3));
T943 = y(68)^(params(46)*params(12)-1);
T944 = T492*T594*T941*T943;
T997 = params(48)^2;
T1000 = exp(y(26)*params(46)*(params(3)-1)*params(12)+T997/2);
T1003 = (y(38)*params(46)*(params(3)-1)*params(12)-T997)/params(48);
T1004 = normcdf(T1003,0,1);
T1009 = (y(39)*params(46)*(params(3)-1)*params(12)-T997)/params(48);
T1010 = normcdf(T1009,0,1);
T1014 = (T997-y(38)*params(46)*(params(3)-1)*params(12))/params(48);
T1015 = normcdf(T1014,0,1);
T1019 = (T997-y(39)*params(46)*(params(3)-1)*params(12))/params(48);
T1020 = normcdf(T1019,0,1);
T1023 = y(38)*params(46)*(params(3)-1)*params(12)/params(48);
T1024 = normcdf(T1023,0,1);
T1026 = y(39)*params(46)*(params(3)-1)*params(12)/params(48);
T1027 = normcdf(T1026,0,1);
T1042 = params(49)^2;
T1045 = exp(params(46)*(params(3)-1)*params(12)*y(73)+T1042/2);
T1048 = (params(46)*(params(3)-1)*params(12)*y(85)-T1042)/params(49);
T1049 = normcdf(T1048,0,1);
T1054 = (params(46)*(params(3)-1)*params(12)*y(86)-T1042)/params(49);
T1055 = normcdf(T1054,0,1);
T1059 = (T1042-params(46)*(params(3)-1)*params(12)*y(85))/params(49);
T1060 = normcdf(T1059,0,1);
T1064 = (T1042-params(46)*(params(3)-1)*params(12)*y(86))/params(49);
T1065 = normcdf(T1064,0,1);
T1068 = params(46)*(params(3)-1)*params(12)*y(85)/params(49);
T1069 = normcdf(T1068,0,1);
T1071 = params(46)*(params(3)-1)*params(12)*y(86)/params(49);
T1072 = normcdf(T1071,0,1);
T1318 = params(3)*params(22)/(params(3)-1);
T1320 = params(21)*y(29)^T1318;
T2130 = (1-params(36)*y(4))^(1-params(5))*(1-params(50))*getPowerDeriv(y(3)-y(3)*params(50),params(5),1)*getPowerDeriv(T25,(-params(2)),1);
T2137 = getPowerDeriv((1-params(36)*y(4))/(y(3)-y(3)*params(50)),1-params(5),1);
T2151 = getPowerDeriv((y(3)-y(3)*params(50))/(1-params(36)*y(4)),params(5),1);
T2163 = getPowerDeriv(T25,(-params(2)),1)*(y(3)-y(3)*params(50))^params(5)*(-params(36))*getPowerDeriv(1-params(36)*y(4),1-params(5),1);
T2236 = (-T443)/(y(9)*y(9))*getPowerDeriv(T445,params(46)-1,1);
T2250 = (-T443)/(y(9)*y(9))*getPowerDeriv(T445,params(46),1);
T2330 = getPowerDeriv(T255,(-params(4)),1);
T2338 = getPowerDeriv(T278,(-params(4)),1);
T2347 = getPowerDeriv(T206,(-params(4)),1);
T2354 = getPowerDeriv(T233,(-params(4)),1);
T2433 = getPowerDeriv(y(21),params(12),1);
T2467 = getPowerDeriv(y(22),params(12),1);
T2529 = T620*getPowerDeriv(T458,params(46)*(1-params(3)*params(12)),1);
T2539 = T620*getPowerDeriv(y(25)*T620,1-params(3)*params(12),1);
T2553 = T620*getPowerDeriv(y(25)*T620,(-params(3))*params(12),1);
T2629 = (-(y(102)*y(104)^params(3)*T427*getPowerDeriv(y(29),params(3)*(-params(22)),1)));
T2710 = getPowerDeriv(y(34),params(46)*T451,1);
T2773 = getPowerDeriv(y(35),params(46)*T451,1);
T2846 = params(46)*(params(3)-1)*params(12)/params(48);
T2872 = T2846*exp((-(T1023*T1023))/2)/2.506628274631;
T2895 = T2846*exp((-(T1026*T1026))/2)/2.506628274631;
T2959 = (1-params(36)*y(51))^(1-params(5))*(1-params(50))*getPowerDeriv(y(50)-params(50)*y(50),params(5),1)*getPowerDeriv(T59,(-params(2)),1);
T2966 = getPowerDeriv((1-params(36)*y(51))/(y(50)-params(50)*y(50)),1-params(5),1);
T2980 = getPowerDeriv((y(50)-params(50)*y(50))/(1-params(36)*y(51)),params(5),1);
T2991 = getPowerDeriv(T59,(-params(2)),1)*(y(50)-params(50)*y(50))^params(5)*(-params(36))*getPowerDeriv(1-params(36)*y(51),1-params(5),1);
T3062 = (-T443)/(y(56)*y(56))*getPowerDeriv(T505,params(46)-1,1);
T3076 = (-T443)/(y(56)*y(56))*getPowerDeriv(T505,params(46),1);
T3143 = getPowerDeriv(T267,(-params(4)),1);
T3151 = getPowerDeriv(T288,(-params(4)),1);
T3159 = getPowerDeriv(T221,(-params(4)),1);
T3166 = getPowerDeriv(T244,(-params(4)),1);
T3245 = getPowerDeriv(y(68),params(12),1);
T3278 = getPowerDeriv(y(69),params(12),1);
T3337 = T620*getPowerDeriv(T511,params(46)*(1-params(3)*params(12)),1);
T3349 = T620*getPowerDeriv(y(72)*T620,1-params(3)*params(12),1);
T3361 = T620*getPowerDeriv(y(72)*T620,(-params(3))*params(12),1);
T3516 = getPowerDeriv(y(81),params(46)*T451,1);
T3570 = getPowerDeriv(y(82),params(46)*T451,1);
T3634 = params(46)*(params(3)-1)*params(12)/params(49);
T3657 = T3634*exp((-(T1068*T1068))/2)/2.506628274631;
T3680 = T3634*exp((-(T1071*T1071))/2)/2.506628274631;
T3760 = getPowerDeriv(T361,T362,1);
T3766 = getPowerDeriv(T380,T362,1);
T3788 = getPowerDeriv(T371,T362,1);
T3794 = getPowerDeriv(T389,T362,1);
T3886 = getPowerDeriv(y(117)/y(123),1-params(3),1);
T3955 = (-(y(102)*y(104)^params(3)*T424*T3/(y(123)*y(123))*getPowerDeriv(T425,(-params(3)),1)));
lhs =y(2);
rhs =params(5)*params(51)*(1-params(34))*T28*T32+params(34)*T41^(-params(2))+params(52)*T35^(-params(2));
residual(1)= lhs-rhs;
lhs =y(49);
rhs =params(5)*params(51)*(1-params(34))*T60*T64+params(34)*T70^(-params(2))+params(52)*T66^(-params(2));
residual(2)= lhs-rhs;
lhs =y(1);
rhs =params(36)*(-params(51))*(1-params(5))*T28*T82-params(34)*y(2)*params(36)*y(4)^params(35)-y(4)^params(35)*params(36)*params(52);
residual(3)= lhs-rhs;
lhs =y(48);
rhs =params(36)*(-params(51))*(1-params(5))*T60*T98-params(34)*params(36)*y(49)*y(51)^params(35)-params(36)*params(52)*y(51)^params(35);
residual(4)= lhs-rhs;
lhs =T112*y(8)/y(13)*(1-params(27)*y(95));
rhs =1;
residual(5)= lhs-rhs;
lhs =T129*(1-params(28)*y(96));
rhs =1;
residual(6)= lhs-rhs;
lhs =T141*(1-params(29)*y(109));
rhs =1;
residual(7)= lhs-rhs;
lhs =T124*y(55)/y(60)*(1-params(30)*y(110));
rhs =1;
residual(8)= lhs-rhs;
lhs =y(16)*params(42)*(y(16)-1);
rhs =params(43)*((-y(1))/y(2)-(params(43)-1)/params(43)*y(25))+y(4)*y(16)*(y(16)-1)*y(2)*params(1)*params(42)/y(2)/y(4);
residual(9)= lhs-rhs;
lhs =y(63)*params(42)*(y(63)-1);
rhs =params(43)*((-y(48))/y(49)-(params(43)-1)/params(43)*y(72))+y(51)*y(63)*(y(63)-1)*y(49)*params(1)*params(42)/y(49)/y(51);
residual(10)= lhs-rhs;
lhs =y(16);
rhs =y(13);
residual(11)= lhs-rhs;
lhs =y(63);
rhs =y(60);
residual(12)= lhs-rhs;
lhs =y(97);
rhs =T210*y(10);
residual(13)= lhs-rhs;
lhs =y(98);
rhs =T223*y(57);
residual(14)= lhs-rhs;
lhs =y(111);
rhs =y(10)*T235;
residual(15)= lhs-rhs;
lhs =y(112);
rhs =y(57)*T246;
residual(16)= lhs-rhs;
lhs =y(99);
rhs =T257*y(7);
residual(17)= lhs-rhs;
lhs =y(100);
rhs =T269*y(54);
residual(18)= lhs-rhs;
lhs =y(113);
rhs =y(7)*T280;
residual(19)= lhs-rhs;
lhs =y(114);
rhs =y(54)*T290;
residual(20)= lhs-rhs;
lhs =y(13)*params(37)*(y(13)-1);
rhs =params(38)*(y(15)-T299)+y(10)*y(13)*(y(13)-1)*T304/y(10);
residual(21)= lhs-rhs;
lhs =y(60)*params(37)*(y(60)-1);
rhs =params(38)*(y(62)-T299)+y(57)*y(60)*(y(60)-1)*T317/y(57);
residual(22)= lhs-rhs;
lhs =y(12)*params(37)*(y(12)-1);
rhs =params(38)*(y(14)-T299*y(11))+y(7)*y(12)*T304*(y(12)-1)/y(7);
residual(23)= lhs-rhs;
lhs =y(59)*params(37)*(y(59)-1);
rhs =params(38)*(y(61)-T299*y(58))+y(54)*y(59)*T317*(y(59)-1)/y(54);
residual(24)= lhs-rhs;
lhs =y(12);
rhs =y(13);
residual(25)= lhs-rhs;
lhs =y(59);
rhs =y(60);
residual(26)= lhs-rhs;
lhs =y(15);
rhs =T361^T362;
residual(27)= lhs-rhs;
lhs =y(62);
rhs =T371^T362;
residual(28)= lhs-rhs;
lhs =y(14);
rhs =T380^T362;
residual(29)= lhs-rhs;
lhs =y(61);
rhs =T389^T362;
residual(30)= lhs-rhs;
lhs =y(8);
rhs =T396*T403;
residual(31)= lhs-rhs;
lhs =y(55);
rhs =T408*T412;
residual(32)= lhs-rhs;
lhs =y(21);
rhs =y(103)^params(3)*y(101)+T432;
residual(33)= lhs-rhs;
lhs =y(22);
rhs =y(103)^params(3)*y(101);
residual(34)= lhs-rhs;
lhs =y(32);
rhs =T448*T453*T463*T472;
residual(35)= lhs-rhs;
lhs =y(33);
rhs =T463*T448*T477*T484;
residual(36)= lhs-rhs;
lhs =y(68);
rhs =y(118)^params(3)*y(116)+T496*y(115);
residual(37)= lhs-rhs;
lhs =y(69);
rhs =y(118)^params(3)*y(116);
residual(38)= lhs-rhs;
lhs =y(79);
rhs =T506*T508*T512*T520;
residual(39)= lhs-rhs;
lhs =y(80);
rhs =T512*T506*T525*T532;
residual(40)= lhs-rhs;
lhs =y(9);
rhs =T112*(y(32)*y(25)*T535/y(34)+y(9)*(1-y(23)));
residual(41)= lhs-rhs;
lhs =y(9);
rhs =T112*(y(33)*y(25)*T535/y(35)+y(9)*(1-y(24)));
residual(42)= lhs-rhs;
lhs =y(56);
rhs =T124*(y(79)*y(72)*T535/y(81)+y(56)*(1-y(70)));
residual(43)= lhs-rhs;
lhs =y(56);
rhs =T124*(y(80)*y(72)*T535/y(82)+y(56)*(1-y(71)));
residual(44)= lhs-rhs;
lhs =y(23);
rhs =params(47)+T574*T472*T453*T575*T580;
residual(45)= lhs-rhs;
lhs =y(24);
rhs =params(47)+T574*T484*T580*T477*T575;
residual(46)= lhs-rhs;
lhs =y(70);
rhs =params(47)+T574*T520*T508*T592*T594;
residual(47)= lhs-rhs;
lhs =y(71);
rhs =params(47)+T574*T532*T594*T525*T592;
residual(48)= lhs-rhs;
lhs =y(9)*(y(34)-y(35))+y(123)*y(72)*params(24);
rhs =T625*T634+T112*(y(36)-y(37));
residual(49)= lhs-rhs;
lhs =y(9)*(y(34)-y(35))+y(123)*y(72)*params(25);
rhs =T112*(y(36)-y(37))+T651*T658;
residual(50)= lhs-rhs;
lhs =y(56)*(y(81)-y(82))+params(24)*y(25)/y(123);
rhs =T675*T684+T124*(y(83)-y(84));
residual(51)= lhs-rhs;
lhs =y(56)*(y(81)-y(82))+params(25)*y(25)/y(123);
rhs =T124*(y(83)-y(84))+T700*T707;
residual(52)= lhs-rhs;
lhs =params(45)*y(9)*y(17)^params(44);
rhs =params(45)*y(9)*(1-params(53))+T628*T718*(y(34)*y(17))^T451*T723*T725;
residual(53)= lhs-rhs;
lhs =params(45)*y(9)*y(18)^params(44);
rhs =params(45)*y(9)*(1-params(53))+T632*T725*T723*T718*(y(34)*y(18))^T451;
residual(54)= lhs-rhs;
lhs =params(45)*y(9)*y(19)^params(44);
rhs =params(45)*y(9)*(1-params(53))+T628*T725*T718*(y(35)*y(19))^T451*T745;
residual(55)= lhs-rhs;
lhs =params(45)*y(9)*y(20)^params(44);
rhs =params(45)*y(9)*(1-params(53))+T632*T725*T745*T718*(y(35)*y(20))^T451;
residual(56)= lhs-rhs;
lhs =params(45)*y(56)*y(64)^params(44);
rhs =(1-params(53))*params(45)*y(56)+T678*T765*(y(81)*y(64))^T451*T769*T771;
residual(57)= lhs-rhs;
lhs =params(45)*y(56)*y(65)^params(44);
rhs =(1-params(53))*params(45)*y(56)+T682*T771*T769*T765*(y(81)*y(65))^T451;
residual(58)= lhs-rhs;
lhs =params(45)*y(56)*y(66)^params(44);
rhs =(1-params(53))*params(45)*y(56)+T678*T771*T765*(y(82)*y(66))^T451*T791;
residual(59)= lhs-rhs;
lhs =params(45)*y(56)*y(67)^params(44);
rhs =(1-params(53))*params(45)*y(56)+T682*T771*T791*T765*(y(82)*y(67))^T451;
residual(60)= lhs-rhs;
lhs =y(36);
rhs =y(32)*y(25)*(T620-1)-y(9)*(y(35)*y(44)+y(34)*y(46)-y(34)*(1-y(23)))-params(24)*y(123)*y(72)*y(46)+T112*(y(37)*y(44)+y(36)*y(46));
residual(61)= lhs-rhs;
lhs =y(37);
rhs =y(33)*y(25)*(T620-1)-y(9)*(y(35)*y(45)+y(34)*y(47)-y(35)*(1-y(24)))-params(25)*y(123)*y(72)*y(47)+T112*(y(37)*y(45)+y(36)*y(47));
residual(62)= lhs-rhs;
lhs =y(83);
rhs =y(79)*y(72)*(T620-1)-y(56)*(y(82)*y(91)+y(81)*y(93)-y(81)*(1-y(70)))-params(24)*y(25)*y(93)/y(123)+T124*(y(84)*y(91)+y(83)*y(93));
residual(63)= lhs-rhs;
lhs =y(84);
rhs =y(80)*y(72)*(T620-1)-y(56)*(y(82)*y(92)+y(81)*y(94)-y(82)*(1-y(71)))-params(25)*y(25)*y(94)/y(123)+T124*(y(84)*y(92)+y(83)*y(94));
residual(64)= lhs-rhs;
lhs =y(103)^(1-params(3));
rhs =(y(123)*y(104))^(1-params(3))*T895+T900*(y(40)*y(29)*T453+y(41)*T477*(1-y(29)));
residual(65)= lhs-rhs;
lhs =y(104)^(1-params(3));
rhs =T448*T915*(y(42)*y(29)*T453+y(43)*T477*(1-y(29)));
residual(66)= lhs-rhs;
lhs =y(118)^(1-params(3));
rhs =T924*T925+T929*(y(87)*y(76)*T508+y(88)*T525*(1-y(76)));
residual(67)= lhs-rhs;
lhs =y(117)^(1-params(3));
rhs =T448*T944*(y(89)*y(76)*T508+y(90)*T525*(1-y(76)));
residual(68)= lhs-rhs;
lhs =y(128);
rhs =T624*T618*T622*(T628-T632);
residual(69)= lhs-rhs;
lhs =y(130);
rhs =(T628-T632)*T650*T618*T622;
residual(70)= lhs-rhs;
lhs =y(129);
rhs =T674*T618*T672*(T678-T682);
residual(71)= lhs-rhs;
lhs =y(131);
rhs =(T678-T682)*T699*T618*T672;
residual(72)= lhs-rhs;
lhs =y(132);
rhs =T112*(y(36)-y(37));
residual(73)= lhs-rhs;
lhs =y(133);
rhs =T124*(y(83)-y(84));
residual(74)= lhs-rhs;
lhs =y(134);
rhs =y(9)*(y(34)-y(35));
residual(75)= lhs-rhs;
lhs =y(135);
rhs =y(56)*(y(81)-y(82));
residual(76)= lhs-rhs;
lhs =y(136);
rhs =y(123)*y(72)*params(24);
residual(77)= lhs-rhs;
lhs =y(137);
rhs =params(24)*y(25)/y(123);
residual(78)= lhs-rhs;
lhs =y(138);
rhs =y(123)*y(72)*params(25);
residual(79)= lhs-rhs;
lhs =y(139);
rhs =params(25)*y(25)/y(123);
residual(80)= lhs-rhs;
lhs =y(38);
rhs =y(30)-y(26);
residual(81)= lhs-rhs;
lhs =y(39);
rhs =y(31)-y(26);
residual(82)= lhs-rhs;
lhs =y(40);
rhs =T1000*T1004;
residual(83)= lhs-rhs;
lhs =y(41);
rhs =T1000*T1010;
residual(84)= lhs-rhs;
lhs =y(42);
rhs =T1000*T1015;
residual(85)= lhs-rhs;
lhs =y(43);
rhs =T1000*T1020;
residual(86)= lhs-rhs;
lhs =y(44);
rhs =T1024;
residual(87)= lhs-rhs;
lhs =y(45);
rhs =T1027;
residual(88)= lhs-rhs;
lhs =y(46);
rhs =1-T1024;
residual(89)= lhs-rhs;
lhs =y(47);
rhs =1-T1027;
residual(90)= lhs-rhs;
lhs =y(85);
rhs =y(77)-y(73);
residual(91)= lhs-rhs;
lhs =y(86);
rhs =y(78)-y(73);
residual(92)= lhs-rhs;
lhs =y(87);
rhs =T1045*T1049;
residual(93)= lhs-rhs;
lhs =y(88);
rhs =T1045*T1055;
residual(94)= lhs-rhs;
lhs =y(89);
rhs =T1045*T1060;
residual(95)= lhs-rhs;
lhs =y(90);
rhs =T1045*T1065;
residual(96)= lhs-rhs;
lhs =y(91);
rhs =T1069;
residual(97)= lhs-rhs;
lhs =y(92);
rhs =T1072;
residual(98)= lhs-rhs;
lhs =y(93);
rhs =1-T1069;
residual(99)= lhs-rhs;
lhs =y(94);
rhs =1-T1072;
residual(100)= lhs-rhs;
lhs =y(6);
rhs =y(7)+y(29)*y(34)*(1-y(23))+y(35)*(1-y(24))*(1-y(29));
residual(101)= lhs-rhs;
lhs =y(53);
rhs =y(54)+y(76)*y(81)*(1-y(70))+y(82)*(1-y(71))*(1-y(76));
residual(102)= lhs-rhs;
residual(103) = y(27);
residual(104) = y(74);
residual(105) = y(28);
residual(106) = y(75);
lhs =y(9);
rhs =(1-params(56))*(y(11)+y(27)+y(7)*y(28)/y(7)-y(7)*y(28)*y(2)*params(1)*(1-params(10))/y(2)/y(7))+params(56)*y(11)*(1+10*(y(7)/y(6)-params(7)));
residual(107)= lhs-rhs;
lhs =y(56);
rhs =(1-params(56))*(y(58)+y(74)+y(54)*y(75)/y(54)-y(54)*y(75)*y(49)*params(1)*(1-params(10))/y(49)/y(54))+params(56)*y(58)*(1+10*(y(54)/y(53)-params(7)));
residual(108)= lhs-rhs;
lhs =y(29);
rhs =y(29)*y(46)+y(47)*(1-y(29));
residual(109)= lhs-rhs;
lhs =y(76);
rhs =y(76)*y(93)+y(94)*(1-y(76));
residual(110)= lhs-rhs;
lhs =y(4);
rhs =y(29)*y(32)+y(33)*(1-y(29))+y(5);
residual(111)= lhs-rhs;
lhs =y(51);
rhs =y(76)*y(79)+y(80)*(1-y(76))+y(52);
residual(112)= lhs-rhs;
lhs =y(5);
rhs =params(24)*y(76)*y(93)+params(25)*y(94)*(1-y(76));
residual(113)= lhs-rhs;
lhs =y(52);
rhs =params(24)*y(29)*y(46)+params(25)*y(47)*(1-y(29));
residual(114)= lhs-rhs;
lhs =y(10);
rhs =y(3)+y(109)*params(29)*y(123)*y(55)*y(109)/y(123);
residual(115)= lhs-rhs;
lhs =y(57);
rhs =y(50)+y(96)*params(28)*y(123)*y(8)*y(96)/y(123);
residual(116)= lhs-rhs;
lhs =y(6);
rhs =y(29)*y(34)+y(35)*(1-y(29));
residual(117)= lhs-rhs;
lhs =y(53);
rhs =y(76)*y(81)+y(82)*(1-y(76));
residual(118)= lhs-rhs;
lhs =y(101);
rhs =y(97)+y(99);
residual(119)= lhs-rhs;
lhs =y(102);
rhs =y(98)+y(100);
residual(120)= lhs-rhs;
lhs =y(115);
rhs =y(111)+y(113);
residual(121)= lhs-rhs;
lhs =y(116);
rhs =y(112)+y(114);
residual(122)= lhs-rhs;
lhs =y(109)+y(95)-y(8)*y(95)-(1-params(29)*y(109))*y(123)*y(55)*y(109)/y(123);
rhs =y(123)*y(104)*y(102)*params(21)-y(117)*y(115);
residual(123)= lhs-rhs;
residual(124) = y(95)+params(21)*y(123)*y(96);
residual(125) = y(110)+y(109)/y(123)/params(21);
lhs =y(26);
rhs =(1-params(23))*params(54)+y(26)*params(23)+x(1)+x(3);
residual(126)= lhs-rhs;
lhs =y(73);
rhs =x(3)+(1-params(23))*params(54)+y(73)*params(23)+x(2);
residual(127)= lhs-rhs;
residual(128) = y(105);
lhs =y(106);
rhs =x(16)+x(14)+exp(y(153))*x(7)+y(106)*params(31)+exp(y(124))*x(4)+y(355)+y(356);
residual(129)= lhs-rhs;
lhs =y(119);
rhs =x(15)+x(14)+exp(y(154))*x(6)+y(355)+exp(y(124))*x(4)+y(119)*params(31)+y(357);
residual(130)= lhs-rhs;
residual(131) = y(120);
residual(132) = y(107);
lhs =y(108);
rhs =x(16)+x(14)+exp(y(153))*x(7)+y(356)+y(355)+exp(y(124))*x(4)+y(108)*params(32);
residual(133)= lhs-rhs;
lhs =y(121);
rhs =x(15)+x(14)+exp(y(154))*x(6)+y(357)+y(355)+exp(y(124))*x(4)+y(121)*params(32);
residual(134)= lhs-rhs;
residual(135) = y(122);
lhs =y(124);
rhs =y(124)*params(33)+x(5);
residual(136)= lhs-rhs;
lhs =y(153);
rhs =y(153)*params(33)+x(11);
residual(137)= lhs-rhs;
lhs =y(154);
rhs =y(154)*params(33)+x(10);
residual(138)= lhs-rhs;
lhs =y(125);
rhs =y(123)*y(104)*y(102)*params(21)-y(117)*y(115);
residual(139)= lhs-rhs;
lhs =y(126);
rhs =y(101)+y(102)*T1320;
residual(140)= lhs-rhs;
lhs =y(127);
rhs =y(116)+y(115)*y(76)^T1318/params(21);
residual(141)= lhs-rhs;
lhs =y(140);
rhs =y(46)*(y(34)-y(34)*(1-y(23)))+y(44)*(y(35)-y(34)*(1-y(23)));
residual(142)= lhs-rhs;
lhs =y(142);
rhs =y(47)*(y(34)-y(35)*(1-y(24)))+y(45)*(y(35)-y(35)*(1-y(24)));
residual(143)= lhs-rhs;
lhs =y(141);
rhs =y(93)*(y(81)-y(81)*(1-y(70)))+y(91)*(y(82)-y(81)*(1-y(70)));
residual(144)= lhs-rhs;
lhs =y(143);
rhs =y(94)*(y(81)-y(82)*(1-y(71)))+y(92)*(y(82)-y(82)*(1-y(71)));
residual(145)= lhs-rhs;
lhs =y(145);
rhs =T628-T632;
residual(146)= lhs-rhs;
lhs =y(146);
rhs =y(119);
residual(147)= lhs-rhs;
lhs =y(147);
rhs =y(106);
residual(148)= lhs-rhs;
lhs =y(144);
rhs =T628-T632;
residual(149)= lhs-rhs;
lhs =y(148);
rhs =T650*T618*T622;
residual(150)= lhs-rhs;
lhs =y(149);
rhs =T432;
residual(151)= lhs-rhs;
lhs =y(150);
rhs =y(36)/y(34)-y(9);
residual(152)= lhs-rhs;
lhs =y(151);
rhs =y(132)-y(134);
residual(153)= lhs-rhs;
lhs =y(152);
rhs =y(8)/y(13);
residual(154)= lhs-rhs;
lhs =y(155);
rhs =1;
residual(155)= lhs-rhs;
lhs =y(156);
rhs =1;
residual(156)= lhs-rhs;
lhs =y(157);
rhs =y(34)*y(156)+y(35)*(1-y(156))-y(34);
residual(157)= lhs-rhs;
lhs =y(158);
rhs =y(46)*y(156)+y(47)*(1-y(156));
residual(158)= lhs-rhs;
lhs =y(159);
rhs =y(34)*y(158)+y(35)*(1-y(158))-y(34);
residual(159)= lhs-rhs;
lhs =y(160);
rhs =y(158)*y(241)+(1-y(158))*y(242);
residual(160)= lhs-rhs;
lhs =y(161);
rhs =y(160)*y(243)+(1-y(160))*y(244)-y(34);
residual(161)= lhs-rhs;
lhs =y(162);
rhs =y(160)*y(245)+(1-y(160))*y(246);
residual(162)= lhs-rhs;
lhs =y(163);
rhs =y(162)*y(247)+(1-y(162))*y(248)-y(34);
residual(163)= lhs-rhs;
lhs =y(164);
rhs =y(162)*y(249)+(1-y(162))*y(250);
residual(164)= lhs-rhs;
lhs =y(165);
rhs =y(164)*y(251)+(1-y(164))*y(252)-y(34);
residual(165)= lhs-rhs;
lhs =y(166);
rhs =y(164)*y(253)+(1-y(164))*y(254);
residual(166)= lhs-rhs;
lhs =y(167);
rhs =y(166)*y(255)+(1-y(166))*y(256)-y(34);
residual(167)= lhs-rhs;
lhs =y(168);
rhs =y(166)*y(257)+(1-y(166))*y(258);
residual(168)= lhs-rhs;
lhs =y(169);
rhs =y(168)*y(259)+(1-y(168))*y(260)-y(34);
residual(169)= lhs-rhs;
lhs =y(170);
rhs =y(168)*y(261)+(1-y(168))*y(262);
residual(170)= lhs-rhs;
lhs =y(171);
rhs =y(170)*y(263)+(1-y(170))*y(264)-y(34);
residual(171)= lhs-rhs;
lhs =y(172);
rhs =y(170)*y(265)+(1-y(170))*y(266);
residual(172)= lhs-rhs;
lhs =y(173);
rhs =y(172)*y(267)+(1-y(172))*y(268)-y(34);
residual(173)= lhs-rhs;
lhs =y(174);
rhs =y(172)*y(269)+(1-y(172))*y(270);
residual(174)= lhs-rhs;
lhs =y(175);
rhs =y(174)*y(271)+(1-y(174))*y(272)-y(34);
residual(175)= lhs-rhs;
lhs =y(176);
rhs =y(174)*y(273)+(1-y(174))*y(274);
residual(176)= lhs-rhs;
lhs =y(177);
rhs =y(176)*y(275)+(1-y(176))*y(276)-y(34);
residual(177)= lhs-rhs;
lhs =y(178);
rhs =y(176)*y(277)+(1-y(176))*y(278);
residual(178)= lhs-rhs;
lhs =y(179);
rhs =y(178)*y(279)+(1-y(178))*y(280)-y(34);
residual(179)= lhs-rhs;
lhs =y(180);
rhs =y(178)*y(281)+(1-y(178))*y(282);
residual(180)= lhs-rhs;
lhs =y(181);
rhs =y(180)*y(283)+(1-y(180))*y(284)-y(34);
residual(181)= lhs-rhs;
lhs =y(182);
rhs =y(180)*y(285)+(1-y(180))*y(286);
residual(182)= lhs-rhs;
lhs =y(183);
rhs =y(182)*y(287)+(1-y(182))*y(288)-y(34);
residual(183)= lhs-rhs;
lhs =y(184);
rhs =y(182)*y(289)+(1-y(182))*y(290);
residual(184)= lhs-rhs;
lhs =y(185);
rhs =y(184)*y(291)+(1-y(184))*y(292)-y(34);
residual(185)= lhs-rhs;
lhs =y(186);
rhs =y(184)*y(293)+(1-y(184))*y(294);
residual(186)= lhs-rhs;
lhs =y(187);
rhs =y(186)*y(295)+(1-y(186))*y(296)-y(34);
residual(187)= lhs-rhs;
lhs =y(188);
rhs =y(186)*y(297)+(1-y(186))*y(298);
residual(188)= lhs-rhs;
lhs =y(189);
rhs =y(188)*y(299)+(1-y(188))*y(300)-y(34);
residual(189)= lhs-rhs;
lhs =y(190);
rhs =y(188)*y(301)+(1-y(188))*y(302);
residual(190)= lhs-rhs;
lhs =y(191);
rhs =y(190)*y(303)+(1-y(190))*y(304)-y(34);
residual(191)= lhs-rhs;
lhs =y(192);
rhs =y(190)*y(305)+(1-y(190))*y(306);
residual(192)= lhs-rhs;
lhs =y(193);
rhs =y(192)*y(307)+(1-y(192))*y(308)-y(34);
residual(193)= lhs-rhs;
lhs =y(194);
rhs =y(192)*y(309)+(1-y(192))*y(310);
residual(194)= lhs-rhs;
lhs =y(195);
rhs =y(194)*y(311)+(1-y(194))*y(312)-y(34);
residual(195)= lhs-rhs;
lhs =y(196);
rhs =y(194)*y(313)+(1-y(194))*y(314);
residual(196)= lhs-rhs;
lhs =y(197);
rhs =y(196)*y(315)+(1-y(196))*y(316)-y(34);
residual(197)= lhs-rhs;
lhs =y(198);
rhs =1;
residual(198)= lhs-rhs;
lhs =y(199);
rhs =1;
residual(199)= lhs-rhs;
lhs =y(200);
rhs =y(35)*y(199)+y(34)*(1-y(199))-y(35);
residual(200)= lhs-rhs;
lhs =y(201);
rhs =y(45)*y(199)+y(44)*(1-y(199));
residual(201)= lhs-rhs;
lhs =y(202);
rhs =y(35)*y(201)+y(34)*(1-y(201))-y(35);
residual(202)= lhs-rhs;
lhs =y(203);
rhs =y(201)*y(317)+(1-y(201))*y(318);
residual(203)= lhs-rhs;
lhs =y(204);
rhs =y(244)*y(203)+y(243)*(1-y(203))-y(35);
residual(204)= lhs-rhs;
lhs =y(205);
rhs =y(203)*y(319)+(1-y(203))*y(320);
residual(205)= lhs-rhs;
lhs =y(206);
rhs =y(248)*y(205)+y(247)*(1-y(205))-y(35);
residual(206)= lhs-rhs;
lhs =y(207);
rhs =y(205)*y(321)+(1-y(205))*y(322);
residual(207)= lhs-rhs;
lhs =y(208);
rhs =y(252)*y(207)+y(251)*(1-y(207))-y(35);
residual(208)= lhs-rhs;
lhs =y(209);
rhs =y(207)*y(323)+(1-y(207))*y(324);
residual(209)= lhs-rhs;
lhs =y(210);
rhs =y(256)*y(209)+y(255)*(1-y(209))-y(35);
residual(210)= lhs-rhs;
lhs =y(211);
rhs =y(209)*y(325)+(1-y(209))*y(326);
residual(211)= lhs-rhs;
lhs =y(212);
rhs =y(260)*y(211)+y(259)*(1-y(211))-y(35);
residual(212)= lhs-rhs;
lhs =y(213);
rhs =y(211)*y(327)+(1-y(211))*y(328);
residual(213)= lhs-rhs;
lhs =y(214);
rhs =y(264)*y(213)+y(263)*(1-y(213))-y(35);
residual(214)= lhs-rhs;
lhs =y(215);
rhs =y(213)*y(329)+(1-y(213))*y(330);
residual(215)= lhs-rhs;
lhs =y(216);
rhs =y(268)*y(215)+y(267)*(1-y(215))-y(35);
residual(216)= lhs-rhs;
lhs =y(217);
rhs =y(215)*y(331)+(1-y(215))*y(332);
residual(217)= lhs-rhs;
lhs =y(218);
rhs =y(272)*y(217)+y(271)*(1-y(217))-y(35);
residual(218)= lhs-rhs;
lhs =y(219);
rhs =y(217)*y(333)+(1-y(217))*y(334);
residual(219)= lhs-rhs;
lhs =y(220);
rhs =y(276)*y(219)+y(275)*(1-y(219))-y(35);
residual(220)= lhs-rhs;
lhs =y(221);
rhs =y(219)*y(335)+(1-y(219))*y(336);
residual(221)= lhs-rhs;
lhs =y(222);
rhs =y(280)*y(221)+y(279)*(1-y(221))-y(35);
residual(222)= lhs-rhs;
lhs =y(223);
rhs =y(221)*y(337)+(1-y(221))*y(338);
residual(223)= lhs-rhs;
lhs =y(224);
rhs =y(284)*y(223)+y(283)*(1-y(223))-y(35);
residual(224)= lhs-rhs;
lhs =y(225);
rhs =y(223)*y(339)+(1-y(223))*y(340);
residual(225)= lhs-rhs;
lhs =y(226);
rhs =y(288)*y(225)+y(287)*(1-y(225))-y(35);
residual(226)= lhs-rhs;
lhs =y(227);
rhs =y(225)*y(341)+(1-y(225))*y(342);
residual(227)= lhs-rhs;
lhs =y(228);
rhs =y(292)*y(227)+y(291)*(1-y(227))-y(35);
residual(228)= lhs-rhs;
lhs =y(229);
rhs =y(227)*y(343)+(1-y(227))*y(344);
residual(229)= lhs-rhs;
lhs =y(230);
rhs =y(296)*y(229)+y(295)*(1-y(229))-y(35);
residual(230)= lhs-rhs;
lhs =y(231);
rhs =y(229)*y(345)+(1-y(229))*y(346);
residual(231)= lhs-rhs;
lhs =y(232);
rhs =y(300)*y(231)+y(299)*(1-y(231))-y(35);
residual(232)= lhs-rhs;
lhs =y(233);
rhs =y(231)*y(347)+(1-y(231))*y(348);
residual(233)= lhs-rhs;
lhs =y(234);
rhs =y(304)*y(233)+y(303)*(1-y(233))-y(35);
residual(234)= lhs-rhs;
lhs =y(235);
rhs =y(233)*y(349)+(1-y(233))*y(350);
residual(235)= lhs-rhs;
lhs =y(236);
rhs =y(308)*y(235)+y(307)*(1-y(235))-y(35);
residual(236)= lhs-rhs;
lhs =y(237);
rhs =y(235)*y(351)+(1-y(235))*y(352);
residual(237)= lhs-rhs;
lhs =y(238);
rhs =y(312)*y(237)+y(311)*(1-y(237))-y(35);
residual(238)= lhs-rhs;
lhs =y(239);
rhs =y(237)*y(353)+(1-y(237))*y(354);
residual(239)= lhs-rhs;
lhs =y(240);
rhs =y(316)*y(239)+y(315)*(1-y(239))-y(35);
residual(240)= lhs-rhs;
lhs =y(241);
rhs =y(46);
residual(241)= lhs-rhs;
lhs =y(242);
rhs =y(47);
residual(242)= lhs-rhs;
lhs =y(243);
rhs =y(34);
residual(243)= lhs-rhs;
lhs =y(244);
rhs =y(35);
residual(244)= lhs-rhs;
lhs =y(245);
rhs =y(241);
residual(245)= lhs-rhs;
lhs =y(246);
rhs =y(242);
residual(246)= lhs-rhs;
lhs =y(247);
rhs =y(243);
residual(247)= lhs-rhs;
lhs =y(248);
rhs =y(244);
residual(248)= lhs-rhs;
lhs =y(249);
rhs =y(245);
residual(249)= lhs-rhs;
lhs =y(250);
rhs =y(246);
residual(250)= lhs-rhs;
lhs =y(251);
rhs =y(247);
residual(251)= lhs-rhs;
lhs =y(252);
rhs =y(248);
residual(252)= lhs-rhs;
lhs =y(253);
rhs =y(249);
residual(253)= lhs-rhs;
lhs =y(254);
rhs =y(250);
residual(254)= lhs-rhs;
lhs =y(255);
rhs =y(251);
residual(255)= lhs-rhs;
lhs =y(256);
rhs =y(252);
residual(256)= lhs-rhs;
lhs =y(257);
rhs =y(253);
residual(257)= lhs-rhs;
lhs =y(258);
rhs =y(254);
residual(258)= lhs-rhs;
lhs =y(259);
rhs =y(255);
residual(259)= lhs-rhs;
lhs =y(260);
rhs =y(256);
residual(260)= lhs-rhs;
lhs =y(261);
rhs =y(257);
residual(261)= lhs-rhs;
lhs =y(262);
rhs =y(258);
residual(262)= lhs-rhs;
lhs =y(263);
rhs =y(259);
residual(263)= lhs-rhs;
lhs =y(264);
rhs =y(260);
residual(264)= lhs-rhs;
lhs =y(265);
rhs =y(261);
residual(265)= lhs-rhs;
lhs =y(266);
rhs =y(262);
residual(266)= lhs-rhs;
lhs =y(267);
rhs =y(263);
residual(267)= lhs-rhs;
lhs =y(268);
rhs =y(264);
residual(268)= lhs-rhs;
lhs =y(269);
rhs =y(265);
residual(269)= lhs-rhs;
lhs =y(270);
rhs =y(266);
residual(270)= lhs-rhs;
lhs =y(271);
rhs =y(267);
residual(271)= lhs-rhs;
lhs =y(272);
rhs =y(268);
residual(272)= lhs-rhs;
lhs =y(273);
rhs =y(269);
residual(273)= lhs-rhs;
lhs =y(274);
rhs =y(270);
residual(274)= lhs-rhs;
lhs =y(275);
rhs =y(271);
residual(275)= lhs-rhs;
lhs =y(276);
rhs =y(272);
residual(276)= lhs-rhs;
lhs =y(277);
rhs =y(273);
residual(277)= lhs-rhs;
lhs =y(278);
rhs =y(274);
residual(278)= lhs-rhs;
lhs =y(279);
rhs =y(275);
residual(279)= lhs-rhs;
lhs =y(280);
rhs =y(276);
residual(280)= lhs-rhs;
lhs =y(281);
rhs =y(277);
residual(281)= lhs-rhs;
lhs =y(282);
rhs =y(278);
residual(282)= lhs-rhs;
lhs =y(283);
rhs =y(279);
residual(283)= lhs-rhs;
lhs =y(284);
rhs =y(280);
residual(284)= lhs-rhs;
lhs =y(285);
rhs =y(281);
residual(285)= lhs-rhs;
lhs =y(286);
rhs =y(282);
residual(286)= lhs-rhs;
lhs =y(287);
rhs =y(283);
residual(287)= lhs-rhs;
lhs =y(288);
rhs =y(284);
residual(288)= lhs-rhs;
lhs =y(289);
rhs =y(285);
residual(289)= lhs-rhs;
lhs =y(290);
rhs =y(286);
residual(290)= lhs-rhs;
lhs =y(291);
rhs =y(287);
residual(291)= lhs-rhs;
lhs =y(292);
rhs =y(288);
residual(292)= lhs-rhs;
lhs =y(293);
rhs =y(289);
residual(293)= lhs-rhs;
lhs =y(294);
rhs =y(290);
residual(294)= lhs-rhs;
lhs =y(295);
rhs =y(291);
residual(295)= lhs-rhs;
lhs =y(296);
rhs =y(292);
residual(296)= lhs-rhs;
lhs =y(297);
rhs =y(293);
residual(297)= lhs-rhs;
lhs =y(298);
rhs =y(294);
residual(298)= lhs-rhs;
lhs =y(299);
rhs =y(295);
residual(299)= lhs-rhs;
lhs =y(300);
rhs =y(296);
residual(300)= lhs-rhs;
lhs =y(301);
rhs =y(297);
residual(301)= lhs-rhs;
lhs =y(302);
rhs =y(298);
residual(302)= lhs-rhs;
lhs =y(303);
rhs =y(299);
residual(303)= lhs-rhs;
lhs =y(304);
rhs =y(300);
residual(304)= lhs-rhs;
lhs =y(305);
rhs =y(301);
residual(305)= lhs-rhs;
lhs =y(306);
rhs =y(302);
residual(306)= lhs-rhs;
lhs =y(307);
rhs =y(303);
residual(307)= lhs-rhs;
lhs =y(308);
rhs =y(304);
residual(308)= lhs-rhs;
lhs =y(309);
rhs =y(305);
residual(309)= lhs-rhs;
lhs =y(310);
rhs =y(306);
residual(310)= lhs-rhs;
lhs =y(311);
rhs =y(307);
residual(311)= lhs-rhs;
lhs =y(312);
rhs =y(308);
residual(312)= lhs-rhs;
lhs =y(313);
rhs =y(309);
residual(313)= lhs-rhs;
lhs =y(314);
rhs =y(310);
residual(314)= lhs-rhs;
lhs =y(315);
rhs =y(311);
residual(315)= lhs-rhs;
lhs =y(316);
rhs =y(312);
residual(316)= lhs-rhs;
lhs =y(317);
rhs =y(45);
residual(317)= lhs-rhs;
lhs =y(318);
rhs =y(44);
residual(318)= lhs-rhs;
lhs =y(319);
rhs =y(317);
residual(319)= lhs-rhs;
lhs =y(320);
rhs =y(318);
residual(320)= lhs-rhs;
lhs =y(321);
rhs =y(319);
residual(321)= lhs-rhs;
lhs =y(322);
rhs =y(320);
residual(322)= lhs-rhs;
lhs =y(323);
rhs =y(321);
residual(323)= lhs-rhs;
lhs =y(324);
rhs =y(322);
residual(324)= lhs-rhs;
lhs =y(325);
rhs =y(323);
residual(325)= lhs-rhs;
lhs =y(326);
rhs =y(324);
residual(326)= lhs-rhs;
lhs =y(327);
rhs =y(325);
residual(327)= lhs-rhs;
lhs =y(328);
rhs =y(326);
residual(328)= lhs-rhs;
lhs =y(329);
rhs =y(327);
residual(329)= lhs-rhs;
lhs =y(330);
rhs =y(328);
residual(330)= lhs-rhs;
lhs =y(331);
rhs =y(329);
residual(331)= lhs-rhs;
lhs =y(332);
rhs =y(330);
residual(332)= lhs-rhs;
lhs =y(333);
rhs =y(331);
residual(333)= lhs-rhs;
lhs =y(334);
rhs =y(332);
residual(334)= lhs-rhs;
lhs =y(335);
rhs =y(333);
residual(335)= lhs-rhs;
lhs =y(336);
rhs =y(334);
residual(336)= lhs-rhs;
lhs =y(337);
rhs =y(335);
residual(337)= lhs-rhs;
lhs =y(338);
rhs =y(336);
residual(338)= lhs-rhs;
lhs =y(339);
rhs =y(337);
residual(339)= lhs-rhs;
lhs =y(340);
rhs =y(338);
residual(340)= lhs-rhs;
lhs =y(341);
rhs =y(339);
residual(341)= lhs-rhs;
lhs =y(342);
rhs =y(340);
residual(342)= lhs-rhs;
lhs =y(343);
rhs =y(341);
residual(343)= lhs-rhs;
lhs =y(344);
rhs =y(342);
residual(344)= lhs-rhs;
lhs =y(345);
rhs =y(343);
residual(345)= lhs-rhs;
lhs =y(346);
rhs =y(344);
residual(346)= lhs-rhs;
lhs =y(347);
rhs =y(345);
residual(347)= lhs-rhs;
lhs =y(348);
rhs =y(346);
residual(348)= lhs-rhs;
lhs =y(349);
rhs =y(347);
residual(349)= lhs-rhs;
lhs =y(350);
rhs =y(348);
residual(350)= lhs-rhs;
lhs =y(351);
rhs =y(349);
residual(351)= lhs-rhs;
lhs =y(352);
rhs =y(350);
residual(352)= lhs-rhs;
lhs =y(353);
rhs =y(351);
residual(353)= lhs-rhs;
lhs =y(354);
rhs =y(352);
residual(354)= lhs-rhs;
lhs =y(355);
rhs =x(8);
residual(355)= lhs-rhs;
lhs =y(356);
rhs =x(13);
residual(356)= lhs-rhs;
lhs =y(357);
rhs =x(12);
residual(357)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(357, 357);

  %
  % Jacobian matrix
  %

  g1(1,2)=1;
  g1(1,3)=(-(T32*params(5)*params(51)*(1-params(34))*T2130+params(5)*params(51)*(1-params(34))*T28*(-((1-params(36)*y(4))*(1-params(50))))/((y(3)-y(3)*params(50))*(y(3)-y(3)*params(50)))*T2137+params(34)*getPowerDeriv(T41,(-params(2)),1)+params(52)*getPowerDeriv(T35,(-params(2)),1)));
  g1(1,4)=(-(T32*params(5)*params(51)*(1-params(34))*T2163+params(5)*params(51)*(1-params(34))*T28*T2137*(-params(36))/(y(3)-y(3)*params(50))+params(34)*getPowerDeriv(T41,(-params(2)),1)*(-(params(36)*getPowerDeriv(y(4),1+params(35),1)/(1+params(35))))));
  g1(2,49)=1;
  g1(2,50)=(-(T64*params(5)*params(51)*(1-params(34))*T2959+params(5)*params(51)*(1-params(34))*T60*(-((1-params(50))*(1-params(36)*y(51))))/((y(50)-params(50)*y(50))*(y(50)-params(50)*y(50)))*T2966+params(34)*getPowerDeriv(T70,(-params(2)),1)+params(52)*getPowerDeriv(T66,(-params(2)),1)));
  g1(2,51)=(-(T64*params(5)*params(51)*(1-params(34))*T2991+params(5)*params(51)*(1-params(34))*T60*T2966*(-params(36))/(y(50)-params(50)*y(50))+params(34)*getPowerDeriv(T70,(-params(2)),1)*(-(params(36)*getPowerDeriv(y(51),1+params(35),1)/(1+params(35))))));
  g1(3,1)=1;
  g1(3,2)=params(34)*params(36)*y(4)^params(35);
  g1(3,3)=(-(params(36)*(-params(51))*(T82*(1-params(5))*T2130+(1-params(5))*T28*(1-params(50))/(1-params(36)*y(4))*T2151)));
  g1(3,4)=(-(params(36)*(-params(51))*(T82*(1-params(5))*T2163+(1-params(5))*T28*T2151*(-((y(3)-y(3)*params(50))*(-params(36))))/((1-params(36)*y(4))*(1-params(36)*y(4))))-params(34)*y(2)*params(36)*getPowerDeriv(y(4),params(35),1)-params(36)*params(52)*getPowerDeriv(y(4),params(35),1)));
  g1(4,48)=1;
  g1(4,49)=params(34)*params(36)*y(51)^params(35);
  g1(4,50)=(-(params(36)*(-params(51))*(T98*(1-params(5))*T2959+(1-params(5))*T60*(1-params(50))/(1-params(36)*y(51))*T2980)));
  g1(4,51)=(-(params(36)*(-params(51))*(T98*(1-params(5))*T2991+(1-params(5))*T60*T2980*(-((y(50)-params(50)*y(50))*(-params(36))))/((1-params(36)*y(51))*(1-params(36)*y(51))))-params(34)*params(36)*y(49)*getPowerDeriv(y(51),params(35),1)-params(36)*params(52)*getPowerDeriv(y(51),params(35),1)));
  g1(5,8)=(1-params(27)*y(95))*T112/y(13);
  g1(5,13)=(1-params(27)*y(95))*(-(T112*y(8)))/(y(13)*y(13));
  g1(5,95)=T112*y(8)/y(13)*(-params(27));
  g1(6,8)=(1-params(28)*y(96))*y(123)*T124/y(13)/y(123);
  g1(6,13)=(1-params(28)*y(96))*y(123)*(-(y(8)*T124))/(y(13)*y(13))/y(123);
  g1(6,96)=T129*(-params(28));
  g1(7,55)=(1-params(29)*y(109))*y(123)*T112/y(60)/y(123);
  g1(7,60)=(1-params(29)*y(109))*y(123)*(-(T112*y(55)))/(y(60)*y(60))/y(123);
  g1(7,109)=T141*(-params(29));
  g1(8,55)=(1-params(30)*y(110))*T124/y(60);
  g1(8,60)=(1-params(30)*y(110))*(-(T124*y(55)))/(y(60)*y(60));
  g1(8,110)=T124*y(55)/y(60)*(-params(30));
  g1(9,1)=(-(params(43)*T3/y(2)));
  g1(9,2)=(-(params(43)*y(1)/(y(2)*y(2))));
  g1(9,16)=params(42)*(y(16)-1)+y(16)*params(42)-y(4)*((y(16)-1)*y(2)*params(1)*params(42)/y(2)+y(16)*y(2)*params(1)*params(42)/y(2))/y(4);
  g1(9,25)=(-(params(43)*(-((params(43)-1)/params(43)))));
  g1(10,48)=(-(params(43)*T3/y(49)));
  g1(10,49)=(-(params(43)*y(48)/(y(49)*y(49))));
  g1(10,63)=params(42)*(y(63)-1)+params(42)*y(63)-y(51)*((y(63)-1)*y(49)*params(1)*params(42)/y(49)+y(63)*y(49)*params(1)*params(42)/y(49))/y(51);
  g1(10,72)=(-(params(43)*(-((params(43)-1)/params(43)))));
  g1(11,13)=T3;
  g1(11,16)=1;
  g1(12,60)=T3;
  g1(12,63)=1;
  g1(13,10)=(-T210);
  g1(13,15)=(-(y(10)*params(13)*exp(y(105))*(-y(103))/(y(15)*y(15))*T2347));
  g1(13,97)=1;
  g1(13,103)=(-(y(10)*params(13)*T2347*exp(y(105))*1/y(15)));
  g1(13,105)=(-(y(10)*params(13)*T206*T2347));
  g1(14,57)=(-T223);
  g1(14,62)=(-(y(57)*params(14)*exp(y(106))*(-y(104))/(y(62)*y(62))*T3159));
  g1(14,98)=1;
  g1(14,104)=(-(y(57)*params(14)*T3159*exp(y(106))*1/y(62)));
  g1(14,106)=(-(y(57)*params(14)*T221*T3159));
  g1(15,10)=(-T235);
  g1(15,15)=(-(y(10)*params(15)*exp(y(119))*(-y(117))/(y(15)*y(15))*T2354));
  g1(15,111)=1;
  g1(15,117)=(-(y(10)*params(15)*T2354*exp(y(119))*1/y(15)));
  g1(15,119)=(-(y(10)*params(15)*T233*T2354));
  g1(16,57)=(-T246);
  g1(16,62)=(-(y(57)*params(16)*exp(y(120))*(-y(118))/(y(62)*y(62))*T3166));
  g1(16,112)=1;
  g1(16,118)=(-(y(57)*params(16)*T3166*exp(y(120))*1/y(62)));
  g1(16,120)=(-(y(57)*params(16)*T244*T3166));
  g1(17,7)=(-T257);
  g1(17,14)=(-(y(7)*params(17)*exp(y(107))*(-y(103))/(y(14)*y(14))*T2330));
  g1(17,99)=1;
  g1(17,103)=(-(y(7)*params(17)*T2330*exp(y(107))*1/y(14)));
  g1(17,107)=(-(y(7)*params(17)*T255*T2330));
  g1(18,54)=(-T269);
  g1(18,61)=(-(y(54)*params(18)*exp(y(108))*(-y(104))/(y(61)*y(61))*T3143));
  g1(18,100)=1;
  g1(18,104)=(-(y(54)*params(18)*T3143*exp(y(108))*1/y(61)));
  g1(18,108)=(-(y(54)*params(18)*T267*T3143));
  g1(19,7)=(-T280);
  g1(19,14)=(-(y(7)*params(19)*exp(y(121))*(-y(117))/(y(14)*y(14))*T2338));
  g1(19,113)=1;
  g1(19,117)=(-(y(7)*params(19)*T2338*exp(y(121))*1/y(14)));
  g1(19,121)=(-(y(7)*params(19)*T278*T2338));
  g1(20,54)=(-T290);
  g1(20,61)=(-(y(54)*params(20)*exp(y(122))*(-y(118))/(y(61)*y(61))*T3151));
  g1(20,114)=1;
  g1(20,118)=(-(y(54)*params(20)*T3151*exp(y(122))*1/y(61)));
  g1(20,122)=(-(y(54)*params(20)*T288*T3151));
  g1(21,13)=params(37)*(y(13)-1)+y(13)*params(37)-y(10)*((y(13)-1)*T304+y(13)*T304)/y(10);
  g1(21,15)=(-params(38));
  g1(22,60)=params(37)*(y(60)-1)+y(60)*params(37)-y(57)*((y(60)-1)*T317+y(60)*T317)/y(57);
  g1(22,62)=(-params(38));
  g1(23,11)=(-(params(38)*(-T299)));
  g1(23,12)=params(37)*(y(12)-1)+params(37)*y(12)-y(7)*(T304*(y(12)-1)+T304*y(12))/y(7);
  g1(23,14)=(-params(38));
  g1(24,58)=(-(params(38)*(-T299)));
  g1(24,59)=params(37)*(y(59)-1)+params(37)*y(59)-y(54)*(T317*(y(59)-1)+T317*y(59))/y(54);
  g1(24,61)=(-params(38));
  g1(25,12)=1;
  g1(25,13)=T3;
  g1(26,59)=1;
  g1(26,60)=T3;
  g1(27,15)=1;
  g1(27,103)=(-(params(13)*exp(y(105))*getPowerDeriv(y(103)*exp(y(105)),1-params(4),1)*T3760));
  g1(27,105)=(-(T3760*params(13)*y(103)*exp(y(105))*getPowerDeriv(y(103)*exp(y(105)),1-params(4),1)));
  g1(27,117)=(-(T3760*params(15)*exp(y(119))*getPowerDeriv(y(117)*exp(y(119)),1-params(4),1)));
  g1(27,119)=(-(T3760*params(15)*y(117)*exp(y(119))*getPowerDeriv(y(117)*exp(y(119)),1-params(4),1)));
  g1(28,62)=1;
  g1(28,104)=(-(params(14)*exp(y(106))*getPowerDeriv(y(104)*exp(y(106)),1-params(4),1)*T3788));
  g1(28,106)=(-(T3788*params(14)*y(104)*exp(y(106))*getPowerDeriv(y(104)*exp(y(106)),1-params(4),1)));
  g1(28,118)=(-(T3788*params(16)*exp(y(120))*getPowerDeriv(y(118)*exp(y(120)),1-params(4),1)));
  g1(28,120)=(-(T3788*params(16)*y(118)*exp(y(120))*getPowerDeriv(y(118)*exp(y(120)),1-params(4),1)));
  g1(29,14)=1;
  g1(29,103)=(-(params(17)*exp(y(107))*getPowerDeriv(y(103)*exp(y(107)),1-params(4),1)*T3766));
  g1(29,107)=(-(T3766*params(17)*y(103)*exp(y(107))*getPowerDeriv(y(103)*exp(y(107)),1-params(4),1)));
  g1(29,117)=(-(T3766*params(19)*exp(y(121))*getPowerDeriv(y(117)*exp(y(121)),1-params(4),1)));
  g1(29,121)=(-(T3766*params(19)*y(117)*exp(y(121))*getPowerDeriv(y(117)*exp(y(121)),1-params(4),1)));
  g1(30,61)=1;
  g1(30,104)=(-(params(18)*exp(y(108))*getPowerDeriv(y(104)*exp(y(108)),1-params(4),1)*T3794));
  g1(30,108)=(-(T3794*params(18)*y(104)*exp(y(108))*getPowerDeriv(y(104)*exp(y(108)),1-params(4),1)));
  g1(30,118)=(-(T3794*params(20)*exp(y(122))*getPowerDeriv(y(118)*exp(y(122)),1-params(4),1)));
  g1(30,122)=(-(T3794*params(20)*y(118)*exp(y(122))*getPowerDeriv(y(118)*exp(y(122)),1-params(4),1)));
  g1(31,8)=1-T403*T392*1/T392*getPowerDeriv(y(8)/T392,params(39),1);
  g1(31,13)=(-(T396*(y(13)^params(41)*getPowerDeriv(y(13),params(40),1)+y(13)^params(40)*getPowerDeriv(y(13),params(41),1))*getPowerDeriv(T401,1-params(39),1)));
  g1(32,55)=1-T412*T392*1/T392*getPowerDeriv(y(55)/T392,params(39),1);
  g1(32,60)=(-(T408*(y(60)^params(41)*getPowerDeriv(y(60),params(40),1)+y(60)^params(40)*getPowerDeriv(y(60),params(41),1))*getPowerDeriv(T411,1-params(39),1)));
  g1(33,21)=1;
  g1(33,29)=T2629;
  g1(33,101)=(-(y(103)^params(3)));
  g1(33,102)=(-T430);
  g1(33,103)=(-(y(101)*getPowerDeriv(y(103),params(3),1)));
  g1(33,104)=(-(y(102)*T424*T427*getPowerDeriv(y(104),params(3),1)));
  g1(33,123)=T3955;
  g1(34,22)=1;
  g1(34,101)=(-(y(103)^params(3)));
  g1(34,103)=(-(y(101)*getPowerDeriv(y(103),params(3),1)));
  g1(35,9)=(-(T472*T463*T453*T2236));
  g1(35,21)=(-(T448*T453*T463*y(42)*getPowerDeriv(y(21),params(46)*params(12),1)));
  g1(35,22)=(-(T448*T453*T463*y(40)*getPowerDeriv(y(22),params(46)*params(12),1)));
  g1(35,25)=(-(T472*T448*T453*T620*getPowerDeriv(T458,params(46)+params(46)*(-params(3))*params(12)-1,1)));
  g1(35,32)=1;
  g1(35,34)=(-(T472*T463*T448*T2710));
  g1(35,40)=(-(T448*T453*T463*T467));
  g1(35,42)=(-(T448*T453*T463*T470));
  g1(36,9)=(-(T484*T463*T477*T2236));
  g1(36,21)=(-(T463*T448*T477*y(43)*getPowerDeriv(y(21),params(46)*params(12),1)));
  g1(36,22)=(-(T463*T448*T477*y(41)*getPowerDeriv(y(22),params(46)*params(12),1)));
  g1(36,25)=(-(T484*T448*T477*T620*getPowerDeriv(T458,params(46)+params(46)*(-params(3))*params(12)-1,1)));
  g1(36,33)=1;
  g1(36,35)=(-(T484*T463*T448*T2773));
  g1(36,41)=(-(T467*T463*T448*T477));
  g1(36,43)=(-(T470*T463*T448*T477));
  g1(37,68)=1;
  g1(37,76)=(-(y(115)*y(117)^params(3)*y(123)^(-params(3))*getPowerDeriv(y(76),params(3)*(-params(22)),1)));
  g1(37,115)=(-T496);
  g1(37,116)=(-(y(118)^params(3)));
  g1(37,117)=(-(y(115)*T494*getPowerDeriv(y(117),params(3),1)));
  g1(37,118)=(-(y(116)*getPowerDeriv(y(118),params(3),1)));
  g1(37,123)=(-(y(115)*y(117)^params(3)*T492*getPowerDeriv(y(123),(-params(3)),1)));
  g1(38,69)=1;
  g1(38,116)=(-(y(118)^params(3)));
  g1(38,118)=(-(y(116)*getPowerDeriv(y(118),params(3),1)));
  g1(39,56)=(-(T520*T512*T508*T3062));
  g1(39,68)=(-(T506*T508*T512*y(89)*getPowerDeriv(y(68),params(46)*params(12),1)));
  g1(39,69)=(-(T506*T508*T512*y(87)*getPowerDeriv(y(69),params(46)*params(12),1)));
  g1(39,72)=(-(T520*T506*T508*T620*getPowerDeriv(T511,params(46)+params(46)*(-params(3))*params(12)-1,1)));
  g1(39,79)=1;
  g1(39,81)=(-(T520*T512*T506*T3516));
  g1(39,87)=(-(T506*T508*T512*T515));
  g1(39,89)=(-(T506*T508*T512*T518));
  g1(40,56)=(-(T532*T512*T525*T3062));
  g1(40,68)=(-(T512*T506*T525*y(90)*getPowerDeriv(y(68),params(46)*params(12),1)));
  g1(40,69)=(-(T512*T506*T525*y(88)*getPowerDeriv(y(69),params(46)*params(12),1)));
  g1(40,72)=(-(T532*T506*T525*T620*getPowerDeriv(T511,params(46)+params(46)*(-params(3))*params(12)-1,1)));
  g1(40,80)=1;
  g1(40,82)=(-(T532*T512*T506*T3570));
  g1(40,88)=(-(T515*T512*T506*T525));
  g1(40,90)=(-(T518*T512*T506*T525));
  g1(41,9)=1-T112*(1-y(23));
  g1(41,23)=(-(T112*(-y(9))));
  g1(41,25)=(-(T112*y(32)*T535/y(34)));
  g1(41,32)=(-(T112*y(25)*T535/y(34)));
  g1(41,34)=(-(T112*(-(y(32)*y(25)*T535))/(y(34)*y(34))));
  g1(42,9)=1-T112*(1-y(24));
  g1(42,24)=(-(T112*(-y(9))));
  g1(42,25)=(-(T112*y(33)*T535/y(35)));
  g1(42,33)=(-(T112*y(25)*T535/y(35)));
  g1(42,35)=(-(T112*(-(y(33)*y(25)*T535))/(y(35)*y(35))));
  g1(43,56)=1-T124*(1-y(70));
  g1(43,70)=(-(T124*(-y(56))));
  g1(43,72)=(-(T124*y(79)*T535/y(81)));
  g1(43,79)=(-(T124*y(72)*T535/y(81)));
  g1(43,81)=(-(T124*(-(y(79)*y(72)*T535))/(y(81)*y(81))));
  g1(44,56)=1-T124*(1-y(71));
  g1(44,71)=(-(T124*(-y(56))));
  g1(44,72)=(-(T124*y(80)*T535/y(82)));
  g1(44,80)=(-(T124*y(72)*T535/y(82)));
  g1(44,82)=(-(T124*(-(y(80)*y(72)*T535))/(y(82)*y(82))));
  g1(45,9)=(-(T574*T472*T580*T453*T2250));
  g1(45,21)=(-(T574*T453*T575*T580*y(42)*getPowerDeriv(y(21),params(46)*params(12),1)));
  g1(45,22)=(-(T574*T453*T575*T580*y(40)*getPowerDeriv(y(22),params(46)*params(12),1)));
  g1(45,23)=1;
  g1(45,25)=(-(T574*T472*T453*T575*T2529));
  g1(45,34)=(-(T574*T472*T580*T575*T2710));
  g1(45,40)=(-(T574*T467*T453*T575*T580));
  g1(45,42)=(-(T574*T470*T453*T575*T580));
  g1(46,9)=(-(T574*T484*T580*T477*T2250));
  g1(46,21)=(-(T574*T580*T477*T575*y(43)*getPowerDeriv(y(21),params(46)*params(12),1)));
  g1(46,22)=(-(T574*T580*T477*T575*y(41)*getPowerDeriv(y(22),params(46)*params(12),1)));
  g1(46,24)=1;
  g1(46,25)=(-(T574*T484*T477*T575*T2529));
  g1(46,35)=(-(T574*T484*T580*T575*T2773));
  g1(46,41)=(-(T574*T467*T580*T477*T575));
  g1(46,43)=(-(T574*T470*T580*T477*T575));
  g1(47,56)=(-(T574*T520*T594*T508*T3076));
  g1(47,68)=(-(T574*T508*T592*T594*y(89)*getPowerDeriv(y(68),params(46)*params(12),1)));
  g1(47,69)=(-(T574*T508*T592*T594*y(87)*getPowerDeriv(y(69),params(46)*params(12),1)));
  g1(47,70)=1;
  g1(47,72)=(-(T574*T520*T508*T592*T3337));
  g1(47,81)=(-(T574*T520*T594*T592*T3516));
  g1(47,87)=(-(T574*T515*T508*T592*T594));
  g1(47,89)=(-(T574*T518*T508*T592*T594));
  g1(48,56)=(-(T574*T532*T594*T525*T3076));
  g1(48,68)=(-(T574*T594*T525*T592*y(90)*getPowerDeriv(y(68),params(46)*params(12),1)));
  g1(48,69)=(-(T574*T594*T525*T592*y(88)*getPowerDeriv(y(69),params(46)*params(12),1)));
  g1(48,71)=1;
  g1(48,72)=(-(T574*T532*T525*T592*T3337));
  g1(48,82)=(-(T574*T532*T594*T592*T3570));
  g1(48,88)=(-(T574*T515*T594*T525*T592));
  g1(48,90)=(-(T574*T518*T594*T525*T592));
  g1(49,9)=y(34)-y(35);
  g1(49,17)=(-(T625*T628*getPowerDeriv(y(17),T451,1)));
  g1(49,18)=(-(T625*(-(T632*getPowerDeriv(y(18),T451,1)))));
  g1(49,21)=(-(T625*y(17)^T451*T2433));
  g1(49,22)=(-(T625*(-(y(18)^T451*T2467))));
  g1(49,25)=(-(T634*T624*exp(y(30))^((params(3)-1)*params(12))*T618*T2539));
  g1(49,30)=(-(T634*T624*T622*T618*exp(y(30))*getPowerDeriv(exp(y(30)),(params(3)-1)*params(12),1)));
  g1(49,34)=y(9)-T634*exp(y(30))^((params(3)-1)*params(12))*T618*T622*getPowerDeriv(y(34),T451,1);
  g1(49,35)=(-y(9));
  g1(49,36)=(-T112);
  g1(49,37)=T112;
  g1(49,72)=y(123)*params(24);
  g1(49,123)=y(72)*params(24);
  g1(50,9)=y(34)-y(35);
  g1(50,19)=(-(T651*T628*getPowerDeriv(y(19),T451,1)));
  g1(50,20)=(-(T651*(-(T632*getPowerDeriv(y(20),T451,1)))));
  g1(50,21)=(-(T651*y(19)^T451*T2433));
  g1(50,22)=(-(T651*(-(y(20)^T451*T2467))));
  g1(50,25)=(-(T658*T650*T618*exp(y(31))^((params(3)-1)*params(12))*T2539));
  g1(50,31)=(-(T658*T650*T622*T618*exp(y(31))*getPowerDeriv(exp(y(31)),(params(3)-1)*params(12),1)));
  g1(50,34)=y(9);
  g1(50,35)=(-y(9))-T658*T622*T618*exp(y(31))^((params(3)-1)*params(12))*getPowerDeriv(y(35),T451,1);
  g1(50,36)=(-T112);
  g1(50,37)=T112;
  g1(50,72)=y(123)*params(25);
  g1(50,123)=y(72)*params(25);
  g1(51,25)=T425*params(24);
  g1(51,56)=y(81)-y(82);
  g1(51,64)=(-(T675*T678*getPowerDeriv(y(64),T451,1)));
  g1(51,65)=(-(T675*(-(T682*getPowerDeriv(y(65),T451,1)))));
  g1(51,68)=(-(T675*y(64)^T451*T3245));
  g1(51,69)=(-(T675*(-(y(65)^T451*T3278))));
  g1(51,72)=(-(T684*T674*T618*exp(y(77))^((params(3)-1)*params(12))*T3349));
  g1(51,77)=(-(T684*T674*T672*T618*exp(y(77))*getPowerDeriv(exp(y(77)),(params(3)-1)*params(12),1)));
  g1(51,81)=y(56)-T684*T618*exp(y(77))^((params(3)-1)*params(12))*T672*getPowerDeriv(y(81),T451,1);
  g1(51,82)=(-y(56));
  g1(51,83)=(-T124);
  g1(51,84)=T124;
  g1(51,123)=params(24)*(-y(25))/(y(123)*y(123));
  g1(52,25)=T425*params(25);
  g1(52,56)=y(81)-y(82);
  g1(52,66)=(-(T700*T678*getPowerDeriv(y(66),T451,1)));
  g1(52,67)=(-(T700*(-(T682*getPowerDeriv(y(67),T451,1)))));
  g1(52,68)=(-(T700*y(66)^T451*T3245));
  g1(52,69)=(-(T700*(-(y(67)^T451*T3278))));
  g1(52,72)=(-(T707*T699*T618*exp(y(78))^((params(3)-1)*params(12))*T3349));
  g1(52,78)=(-(T707*T699*T672*T618*exp(y(78))*getPowerDeriv(exp(y(78)),(params(3)-1)*params(12),1)));
  g1(52,81)=y(56);
  g1(52,82)=(-y(56))-T707*T672*T618*exp(y(78))^((params(3)-1)*params(12))*getPowerDeriv(y(82),T451,1);
  g1(52,83)=(-T124);
  g1(52,84)=T124;
  g1(52,123)=params(25)*(-y(25))/(y(123)*y(123));
  g1(53,9)=params(45)*y(17)^params(44)-params(45)*(1-params(53));
  g1(53,17)=params(45)*y(9)*getPowerDeriv(y(17),params(44),1)-T628*T725*T723*T718*y(34)*getPowerDeriv(y(34)*y(17),T451,1);
  g1(53,21)=(-(T718*(y(34)*y(17))^T451*T723*T725*T2433));
  g1(53,25)=(-(T628*(T725*T723*T717*(y(34)*y(17))^T451+T718*(y(34)*y(17))^T451*T723*T2553)));
  g1(53,30)=(-(T628*T725*T718*(y(34)*y(17))^T451*exp(y(30))*getPowerDeriv(exp(y(30)),T722,1)));
  g1(53,34)=(-(T628*T725*T723*T718*y(17)*getPowerDeriv(y(34)*y(17),T451,1)));
  g1(54,9)=params(45)*y(18)^params(44)-params(45)*(1-params(53));
  g1(54,18)=params(45)*y(9)*getPowerDeriv(y(18),params(44),1)-T632*T725*T723*T718*y(34)*getPowerDeriv(y(34)*y(18),T451,1);
  g1(54,22)=(-(T725*T723*T718*(y(34)*y(18))^T451*T2467));
  g1(54,25)=(-(T632*(T723*T718*(y(34)*y(18))^T451*T2553+T725*T723*T717*(y(34)*y(18))^T451)));
  g1(54,30)=(-(T632*T725*T718*(y(34)*y(18))^T451*exp(y(30))*getPowerDeriv(exp(y(30)),T722,1)));
  g1(54,34)=(-(T632*T725*T723*T718*y(18)*getPowerDeriv(y(34)*y(18),T451,1)));
  g1(55,9)=params(45)*y(19)^params(44)-params(45)*(1-params(53));
  g1(55,19)=params(45)*y(9)*getPowerDeriv(y(19),params(44),1)-T628*T725*T745*T718*y(35)*getPowerDeriv(y(35)*y(19),T451,1);
  g1(55,21)=(-(T725*T718*(y(35)*y(19))^T451*T745*T2433));
  g1(55,25)=(-(T628*(T718*(y(35)*y(19))^T451*T745*T2553+T725*T745*T717*(y(35)*y(19))^T451)));
  g1(55,31)=(-(T628*T725*T718*(y(35)*y(19))^T451*exp(y(31))*getPowerDeriv(exp(y(31)),T722,1)));
  g1(55,35)=(-(T628*T725*T745*T718*y(19)*getPowerDeriv(y(35)*y(19),T451,1)));
  g1(56,9)=params(45)*y(20)^params(44)-params(45)*(1-params(53));
  g1(56,20)=params(45)*y(9)*getPowerDeriv(y(20),params(44),1)-T632*T725*T745*T718*y(35)*getPowerDeriv(y(35)*y(20),T451,1);
  g1(56,22)=(-(T725*T745*T718*(y(35)*y(20))^T451*T2467));
  g1(56,25)=(-(T632*(T745*T718*(y(35)*y(20))^T451*T2553+T725*T745*T717*(y(35)*y(20))^T451)));
  g1(56,31)=(-(T632*T725*T718*(y(35)*y(20))^T451*exp(y(31))*getPowerDeriv(exp(y(31)),T722,1)));
  g1(56,35)=(-(T632*T725*T745*T718*y(20)*getPowerDeriv(y(35)*y(20),T451,1)));
  g1(57,56)=params(45)*y(64)^params(44)-params(45)*(1-params(53));
  g1(57,64)=params(45)*y(56)*getPowerDeriv(y(64),params(44),1)-T678*T771*T769*T765*y(81)*getPowerDeriv(y(81)*y(64),T451,1);
  g1(57,68)=(-(T765*(y(81)*y(64))^T451*T769*T771*T3245));
  g1(57,72)=(-(T678*(T771*T769*T717*(y(81)*y(64))^T451+T765*(y(81)*y(64))^T451*T769*T3361)));
  g1(57,77)=(-(T678*T771*T765*(y(81)*y(64))^T451*exp(y(77))*getPowerDeriv(exp(y(77)),T722,1)));
  g1(57,81)=(-(T678*T771*T769*T765*y(64)*getPowerDeriv(y(81)*y(64),T451,1)));
  g1(58,56)=params(45)*y(65)^params(44)-params(45)*(1-params(53));
  g1(58,65)=params(45)*y(56)*getPowerDeriv(y(65),params(44),1)-T682*T771*T769*T765*y(81)*getPowerDeriv(y(81)*y(65),T451,1);
  g1(58,69)=(-(T771*T769*T765*(y(81)*y(65))^T451*T3278));
  g1(58,72)=(-(T682*(T769*T765*(y(81)*y(65))^T451*T3361+T771*T769*T717*(y(81)*y(65))^T451)));
  g1(58,77)=(-(T682*T771*T765*(y(81)*y(65))^T451*exp(y(77))*getPowerDeriv(exp(y(77)),T722,1)));
  g1(58,81)=(-(T682*T771*T769*T765*y(65)*getPowerDeriv(y(81)*y(65),T451,1)));
  g1(59,56)=params(45)*y(66)^params(44)-params(45)*(1-params(53));
  g1(59,66)=params(45)*y(56)*getPowerDeriv(y(66),params(44),1)-T678*T771*T791*T765*y(82)*getPowerDeriv(y(82)*y(66),T451,1);
  g1(59,68)=(-(T771*T765*(y(82)*y(66))^T451*T791*T3245));
  g1(59,72)=(-(T678*(T765*(y(82)*y(66))^T451*T791*T3361+T771*T791*T717*(y(82)*y(66))^T451)));
  g1(59,78)=(-(T678*T771*T765*(y(82)*y(66))^T451*exp(y(78))*getPowerDeriv(exp(y(78)),T722,1)));
  g1(59,82)=(-(T678*T771*T791*T765*y(66)*getPowerDeriv(y(82)*y(66),T451,1)));
  g1(60,56)=params(45)*y(67)^params(44)-params(45)*(1-params(53));
  g1(60,67)=params(45)*y(56)*getPowerDeriv(y(67),params(44),1)-T682*T771*T791*T765*y(82)*getPowerDeriv(y(82)*y(67),T451,1);
  g1(60,69)=(-(T771*T791*T765*(y(82)*y(67))^T451*T3278));
  g1(60,72)=(-(T682*(T791*T765*(y(82)*y(67))^T451*T3361+T771*T791*T717*(y(82)*y(67))^T451)));
  g1(60,78)=(-(T682*T771*T765*(y(82)*y(67))^T451*exp(y(78))*getPowerDeriv(exp(y(78)),T722,1)));
  g1(60,82)=(-(T682*T771*T791*T765*y(67)*getPowerDeriv(y(82)*y(67),T451,1)));
  g1(61,9)=y(35)*y(44)+y(34)*y(46)-y(34)*(1-y(23));
  g1(61,23)=y(9)*y(34);
  g1(61,25)=(-(y(32)*(T620-1)));
  g1(61,32)=(-(y(25)*(T620-1)));
  g1(61,34)=y(9)*(y(46)-(1-y(23)));
  g1(61,35)=y(9)*y(44);
  g1(61,36)=1-T112*y(46);
  g1(61,37)=(-(T112*y(44)));
  g1(61,44)=(-((-(y(9)*y(35)))+T112*y(37)));
  g1(61,46)=(-((-(y(9)*y(34)))-y(123)*y(72)*params(24)+T112*y(36)));
  g1(61,72)=params(24)*y(123)*y(46);
  g1(61,123)=params(24)*y(72)*y(46);
  g1(62,9)=y(35)*y(45)+y(34)*y(47)-y(35)*(1-y(24));
  g1(62,24)=y(9)*y(35);
  g1(62,25)=(-(y(33)*(T620-1)));
  g1(62,33)=(-(y(25)*(T620-1)));
  g1(62,34)=y(9)*y(47);
  g1(62,35)=y(9)*(y(45)-(1-y(24)));
  g1(62,36)=(-(T112*y(47)));
  g1(62,37)=1-T112*y(45);
  g1(62,45)=(-((-(y(9)*y(35)))+T112*y(37)));
  g1(62,47)=(-(T112*y(36)+(-(y(9)*y(34)))-y(123)*y(72)*params(25)));
  g1(62,72)=params(25)*y(123)*y(47);
  g1(62,123)=params(25)*y(72)*y(47);
  g1(63,25)=params(24)*y(93)/y(123);
  g1(63,56)=y(82)*y(91)+y(81)*y(93)-y(81)*(1-y(70));
  g1(63,70)=y(56)*y(81);
  g1(63,72)=(-(y(79)*(T620-1)));
  g1(63,79)=(-(y(72)*(T620-1)));
  g1(63,81)=y(56)*(y(93)-(1-y(70)));
  g1(63,82)=y(56)*y(91);
  g1(63,83)=1-T124*y(93);
  g1(63,84)=(-(T124*y(91)));
  g1(63,91)=(-((-(y(56)*y(82)))+T124*y(84)));
  g1(63,93)=(-((-(y(56)*y(81)))-params(24)*y(25)/y(123)+T124*y(83)));
  g1(63,123)=params(24)*(-(y(25)*y(93)))/(y(123)*y(123));
  g1(64,25)=params(25)*y(94)/y(123);
  g1(64,56)=y(82)*y(92)+y(81)*y(94)-y(82)*(1-y(71));
  g1(64,71)=y(56)*y(82);
  g1(64,72)=(-(y(80)*(T620-1)));
  g1(64,80)=(-(y(72)*(T620-1)));
  g1(64,81)=y(56)*y(94);
  g1(64,82)=y(56)*(y(92)-(1-y(71)));
  g1(64,83)=(-(T124*y(94)));
  g1(64,84)=1-T124*y(92);
  g1(64,92)=(-((-(y(56)*y(82)))+T124*y(84)));
  g1(64,94)=(-(T124*y(83)+(-(y(56)*y(81)))-params(25)*y(25)/y(123)));
  g1(64,123)=params(25)*(-(y(25)*y(94)))/(y(123)*y(123));
  g1(65,9)=(-((y(40)*y(29)*T453+y(41)*T477*(1-y(29)))*T580*y(22)^(params(46)*params(12)-1)*T2236));
  g1(65,22)=(-((y(40)*y(29)*T453+y(41)*T477*(1-y(29)))*T448*T580*getPowerDeriv(y(22),params(46)*params(12)-1,1)));
  g1(65,25)=(-((y(40)*y(29)*T453+y(41)*T477*(1-y(29)))*T448*y(22)^(params(46)*params(12)-1)*T2529));
  g1(65,29)=(-((y(123)*y(104))^(1-params(3))*getPowerDeriv(y(29),params(3)*params(22),1)+T900*(T453*y(40)+y(41)*(-T477))));
  g1(65,34)=(-(T900*y(40)*y(29)*T2710));
  g1(65,35)=(-(T900*y(41)*(1-y(29))*T2773));
  g1(65,40)=(-(T900*y(29)*T453));
  g1(65,41)=(-(T900*T477*(1-y(29))));
  g1(65,103)=getPowerDeriv(y(103),1-params(3),1);
  g1(65,104)=(-(T895*y(123)*getPowerDeriv(y(123)*y(104),1-params(3),1)));
  g1(65,123)=(-(T895*y(104)*getPowerDeriv(y(123)*y(104),1-params(3),1)));
  g1(66,9)=(-((y(42)*y(29)*T453+y(43)*T477*(1-y(29)))*T915*T2236));
  g1(66,21)=(-((y(42)*y(29)*T453+y(43)*T477*(1-y(29)))*T448*T424*T580*T912*getPowerDeriv(y(21),params(46)*params(12)-1,1)));
  g1(66,25)=(-((y(42)*y(29)*T453+y(43)*T477*(1-y(29)))*T448*T914*T912*T424*T2529));
  g1(66,29)=(-((y(42)*y(29)*T453+y(43)*T477*(1-y(29)))*T448*T914*T912*T580*getPowerDeriv(y(29),params(3)*(-params(22)),1)+T448*T915*(T453*y(42)+y(43)*(-T477))));
  g1(66,34)=(-(T448*T915*y(42)*y(29)*T2710));
  g1(66,35)=(-(T448*T915*y(43)*(1-y(29))*T2773));
  g1(66,42)=(-(y(29)*T453*T448*T915));
  g1(66,43)=(-(T477*(1-y(29))*T448*T915));
  g1(66,104)=getPowerDeriv(y(104),1-params(3),1);
  g1(66,123)=(-((y(42)*y(29)*T453+y(43)*T477*(1-y(29)))*T448*T914*T424*T580*T3/(y(123)*y(123))*getPowerDeriv(T425,1-params(3),1)));
  g1(67,56)=(-((y(87)*y(76)*T508+y(88)*T525*(1-y(76)))*T594*y(69)^(params(46)*params(12)-1)*T3062));
  g1(67,69)=(-((y(87)*y(76)*T508+y(88)*T525*(1-y(76)))*T506*T594*getPowerDeriv(y(69),params(46)*params(12)-1,1)));
  g1(67,72)=(-((y(87)*y(76)*T508+y(88)*T525*(1-y(76)))*T506*y(69)^(params(46)*params(12)-1)*T3337));
  g1(67,76)=(-(T924*getPowerDeriv(y(76),params(3)*params(22),1)+T929*(T508*y(87)+y(88)*(-T525))));
  g1(67,81)=(-(T929*y(87)*y(76)*T3516));
  g1(67,82)=(-(T929*y(88)*(1-y(76))*T3570));
  g1(67,87)=(-(T929*y(76)*T508));
  g1(67,88)=(-(T929*T525*(1-y(76))));
  g1(67,117)=(-(T925*T425*T3886));
  g1(67,118)=getPowerDeriv(y(118),1-params(3),1);
  g1(67,123)=(-(T925*T3886*(-y(117))/(y(123)*y(123))));
  g1(68,9)=(-((y(89)*y(76)*T508+y(90)*T525*(1-y(76)))*T944*T2236));
  g1(68,68)=(-((y(89)*y(76)*T508+y(90)*T525*(1-y(76)))*T448*T492*T594*T941*getPowerDeriv(y(68),params(46)*params(12)-1,1)));
  g1(68,72)=(-((y(89)*y(76)*T508+y(90)*T525*(1-y(76)))*T448*T943*T941*T492*T3337));
  g1(68,76)=(-((y(89)*y(76)*T508+y(90)*T525*(1-y(76)))*T448*T943*T941*T594*getPowerDeriv(y(76),params(3)*(-params(22)),1)+T448*T944*(T508*y(89)+y(90)*(-T525))));
  g1(68,81)=(-(T448*T944*y(89)*y(76)*T3516));
  g1(68,82)=(-(T448*T944*y(90)*(1-y(76))*T3570));
  g1(68,89)=(-(y(76)*T508*T448*T944));
  g1(68,90)=(-(T525*(1-y(76))*T448*T944));
  g1(68,117)=getPowerDeriv(y(117),1-params(3),1);
  g1(68,123)=(-((y(89)*y(76)*T508+y(90)*T525*(1-y(76)))*T448*T943*T492*T594*getPowerDeriv(y(123),1-params(3),1)));
  g1(69,21)=(-(T624*T618*T622*T2433));
  g1(69,22)=(-(T624*T618*T622*(-T2467)));
  g1(69,25)=(-((T628-T632)*T624*T618*T2539));
  g1(69,34)=(-((T628-T632)*T618*T622*getPowerDeriv(y(34),T451,1)));
  g1(69,128)=1;
  g1(70,21)=(-(T650*T618*T622*T2433));
  g1(70,22)=(-(T650*T618*T622*(-T2467)));
  g1(70,25)=(-((T628-T632)*T650*T618*T2539));
  g1(70,35)=(-((T628-T632)*T618*T622*getPowerDeriv(y(35),T451,1)));
  g1(70,130)=1;
  g1(71,68)=(-(T674*T618*T672*T3245));
  g1(71,69)=(-(T674*T618*T672*(-T3278)));
  g1(71,72)=(-((T678-T682)*T674*T618*T3349));
  g1(71,81)=(-((T678-T682)*T618*T672*getPowerDeriv(y(81),T451,1)));
  g1(71,129)=1;
  g1(72,68)=(-(T699*T618*T672*T3245));
  g1(72,69)=(-(T699*T618*T672*(-T3278)));
  g1(72,72)=(-((T678-T682)*T699*T618*T3349));
  g1(72,82)=(-((T678-T682)*T618*T672*getPowerDeriv(y(82),T451,1)));
  g1(72,131)=1;
  g1(73,36)=(-T112);
  g1(73,37)=T112;
  g1(73,132)=1;
  g1(74,83)=(-T124);
  g1(74,84)=T124;
  g1(74,133)=1;
  g1(75,9)=(-(y(34)-y(35)));
  g1(75,34)=(-y(9));
  g1(75,35)=y(9);
  g1(75,134)=1;
  g1(76,56)=(-(y(81)-y(82)));
  g1(76,81)=(-y(56));
  g1(76,82)=y(56);
  g1(76,135)=1;
  g1(77,72)=(-(y(123)*params(24)));
  g1(77,123)=(-(y(72)*params(24)));
  g1(77,136)=1;
  g1(78,25)=(-(T425*params(24)));
  g1(78,123)=(-(params(24)*(-y(25))/(y(123)*y(123))));
  g1(78,137)=1;
  g1(79,72)=(-(y(123)*params(25)));
  g1(79,123)=(-(y(72)*params(25)));
  g1(79,138)=1;
  g1(80,25)=(-(T425*params(25)));
  g1(80,123)=(-(params(25)*(-y(25))/(y(123)*y(123))));
  g1(80,139)=1;
  g1(81,26)=1;
  g1(81,30)=T3;
  g1(81,38)=1;
  g1(82,26)=1;
  g1(82,31)=T3;
  g1(82,39)=1;
  g1(83,26)=(-(T1004*params(46)*(params(3)-1)*params(12)*T1000));
  g1(83,38)=(-(T1000*T2846*exp((-(T1003*T1003))/2)/2.506628274631));
  g1(83,40)=1;
  g1(84,26)=(-(T1010*params(46)*(params(3)-1)*params(12)*T1000));
  g1(84,39)=(-(T1000*T2846*exp((-(T1009*T1009))/2)/2.506628274631));
  g1(84,41)=1;
  g1(85,26)=(-(T1015*params(46)*(params(3)-1)*params(12)*T1000));
  g1(85,38)=(-(T1000*(-(params(46)*(params(3)-1)*params(12)))/params(48)*exp((-(T1014*T1014))/2)/2.506628274631));
  g1(85,42)=1;
  g1(86,26)=(-(T1020*params(46)*(params(3)-1)*params(12)*T1000));
  g1(86,39)=(-(T1000*(-(params(46)*(params(3)-1)*params(12)))/params(48)*exp((-(T1019*T1019))/2)/2.506628274631));
  g1(86,43)=1;
  g1(87,38)=(-T2872);
  g1(87,44)=1;
  g1(88,39)=(-T2895);
  g1(88,45)=1;
  g1(89,38)=T2872;
  g1(89,46)=1;
  g1(90,39)=T2895;
  g1(90,47)=1;
  g1(91,73)=1;
  g1(91,77)=T3;
  g1(91,85)=1;
  g1(92,73)=1;
  g1(92,78)=T3;
  g1(92,86)=1;
  g1(93,73)=(-(T1049*params(46)*(params(3)-1)*params(12)*T1045));
  g1(93,85)=(-(T1045*T3634*exp((-(T1048*T1048))/2)/2.506628274631));
  g1(93,87)=1;
  g1(94,73)=(-(T1055*params(46)*(params(3)-1)*params(12)*T1045));
  g1(94,86)=(-(T1045*T3634*exp((-(T1054*T1054))/2)/2.506628274631));
  g1(94,88)=1;
  g1(95,73)=(-(T1060*params(46)*(params(3)-1)*params(12)*T1045));
  g1(95,85)=(-(T1045*(-(params(46)*(params(3)-1)*params(12)))/params(49)*exp((-(T1059*T1059))/2)/2.506628274631));
  g1(95,89)=1;
  g1(96,73)=(-(T1065*params(46)*(params(3)-1)*params(12)*T1045));
  g1(96,86)=(-(T1045*(-(params(46)*(params(3)-1)*params(12)))/params(49)*exp((-(T1064*T1064))/2)/2.506628274631));
  g1(96,90)=1;
  g1(97,85)=(-T3657);
  g1(97,91)=1;
  g1(98,86)=(-T3680);
  g1(98,92)=1;
  g1(99,85)=T3657;
  g1(99,93)=1;
  g1(100,86)=T3680;
  g1(100,94)=1;
  g1(101,6)=1;
  g1(101,7)=T3;
  g1(101,23)=(-(y(29)*(-y(34))));
  g1(101,24)=(-((1-y(29))*(-y(35))));
  g1(101,29)=(-(y(34)*(1-y(23))-y(35)*(1-y(24))));
  g1(101,34)=(-(y(29)*(1-y(23))));
  g1(101,35)=(-((1-y(24))*(1-y(29))));
  g1(102,53)=1;
  g1(102,54)=T3;
  g1(102,70)=(-(y(76)*(-y(81))));
  g1(102,71)=(-((1-y(76))*(-y(82))));
  g1(102,76)=(-(y(81)*(1-y(70))-y(82)*(1-y(71))));
  g1(102,81)=(-(y(76)*(1-y(70))));
  g1(102,82)=(-((1-y(71))*(1-y(76))));
  g1(103,27)=1;
  g1(104,74)=1;
  g1(105,28)=1;
  g1(106,75)=1;
  g1(107,6)=(-(params(56)*y(11)*10*(-y(7))/(y(6)*y(6))));
  g1(107,7)=(-(params(56)*y(11)*10*1/y(6)));
  g1(107,9)=1;
  g1(107,11)=(-(1-params(56)+params(56)*(1+10*(y(7)/y(6)-params(7)))));
  g1(107,27)=(-(1-params(56)));
  g1(107,28)=(-((1-params(56))*(1-y(7)*y(2)*params(1)*(1-params(10))/y(2)/y(7))));
  g1(108,53)=(-(params(56)*y(58)*10*(-y(54))/(y(53)*y(53))));
  g1(108,54)=(-(params(56)*y(58)*10*1/y(53)));
  g1(108,56)=1;
  g1(108,58)=(-(1-params(56)+params(56)*(1+10*(y(54)/y(53)-params(7)))));
  g1(108,74)=(-(1-params(56)));
  g1(108,75)=(-((1-params(56))*(1-y(54)*y(49)*params(1)*(1-params(10))/y(49)/y(54))));
  g1(109,29)=1-(y(46)-y(47));
  g1(109,46)=(-y(29));
  g1(109,47)=(-(1-y(29)));
  g1(110,76)=1-(y(93)-y(94));
  g1(110,93)=(-y(76));
  g1(110,94)=(-(1-y(76)));
  g1(111,4)=1;
  g1(111,5)=T3;
  g1(111,29)=(-(y(32)-y(33)));
  g1(111,32)=(-y(29));
  g1(111,33)=(-(1-y(29)));
  g1(112,51)=1;
  g1(112,52)=T3;
  g1(112,76)=(-(y(79)-y(80)));
  g1(112,79)=(-y(76));
  g1(112,80)=(-(1-y(76)));
  g1(113,5)=1;
  g1(113,76)=(-(params(24)*y(93)+params(25)*(-y(94))));
  g1(113,93)=(-(y(76)*params(24)));
  g1(113,94)=(-(params(25)*(1-y(76))));
  g1(114,29)=(-(params(24)*y(46)+params(25)*(-y(47))));
  g1(114,46)=(-(y(29)*params(24)));
  g1(114,47)=(-(params(25)*(1-y(29))));
  g1(114,52)=1;
  g1(115,3)=T3;
  g1(115,10)=1;
  g1(115,55)=(-(y(109)*params(29)*y(123)*y(109)/y(123)));
  g1(115,109)=(-(params(29)*y(123)*y(55)*y(109)/y(123)+y(109)*params(29)*y(123)*y(55)/y(123)));
  g1(116,8)=(-(y(96)*params(28)*y(123)*y(96)/y(123)));
  g1(116,50)=T3;
  g1(116,57)=1;
  g1(116,96)=(-(params(28)*y(123)*y(8)*y(96)/y(123)+y(96)*params(28)*y(8)*y(123)/y(123)));
  g1(117,6)=1;
  g1(117,29)=(-(y(34)-y(35)));
  g1(117,34)=(-y(29));
  g1(117,35)=(-(1-y(29)));
  g1(118,53)=1;
  g1(118,76)=(-(y(81)-y(82)));
  g1(118,81)=(-y(76));
  g1(118,82)=(-(1-y(76)));
  g1(119,97)=T3;
  g1(119,99)=T3;
  g1(119,101)=1;
  g1(120,98)=T3;
  g1(120,100)=T3;
  g1(120,102)=1;
  g1(121,111)=T3;
  g1(121,113)=T3;
  g1(121,115)=1;
  g1(122,112)=T3;
  g1(122,114)=T3;
  g1(122,116)=1;
  g1(123,8)=(-y(95));
  g1(123,55)=(-((1-params(29)*y(109))*y(123)*y(109)/y(123)));
  g1(123,95)=1-y(8);
  g1(123,102)=(-(y(123)*y(104)*params(21)));
  g1(123,104)=(-(params(21)*y(123)*y(102)));
  g1(123,109)=1-(y(123)*y(55)*y(109)/y(123)*(-params(29))+(1-params(29)*y(109))*y(123)*y(55)/y(123));
  g1(123,115)=y(117);
  g1(123,117)=y(115);
  g1(123,123)=(-(y(104)*y(102)*params(21)));
  g1(124,95)=1;
  g1(124,96)=y(123)*params(21);
  g1(124,123)=y(96)*params(21);
  g1(125,109)=T425/params(21);
  g1(125,110)=1;
  g1(125,123)=(-y(109))/(y(123)*y(123))/params(21);
  g1(126,26)=1-params(23);
  g1(127,73)=1-params(23);
  g1(128,105)=1;
  g1(129,106)=1-params(31);
  g1(129,124)=(-(exp(y(124))*x(4)));
  g1(129,153)=(-(exp(y(153))*x(7)));
  g1(129,355)=T3;
  g1(129,356)=T3;
  g1(130,119)=1-params(31);
  g1(130,124)=(-(exp(y(124))*x(4)));
  g1(130,154)=(-(exp(y(154))*x(6)));
  g1(130,355)=T3;
  g1(130,357)=T3;
  g1(131,120)=1;
  g1(132,107)=1;
  g1(133,108)=1-params(32);
  g1(133,124)=(-(exp(y(124))*x(4)));
  g1(133,153)=(-(exp(y(153))*x(7)));
  g1(133,355)=T3;
  g1(133,356)=T3;
  g1(134,121)=1-params(32);
  g1(134,124)=(-(exp(y(124))*x(4)));
  g1(134,154)=(-(exp(y(154))*x(6)));
  g1(134,355)=T3;
  g1(134,357)=T3;
  g1(135,122)=1;
  g1(136,124)=1-params(33);
  g1(137,153)=1-params(33);
  g1(138,154)=1-params(33);
  g1(139,102)=(-(y(123)*y(104)*params(21)));
  g1(139,104)=(-(params(21)*y(123)*y(102)));
  g1(139,115)=y(117);
  g1(139,117)=y(115);
  g1(139,123)=(-(y(104)*y(102)*params(21)));
  g1(139,125)=1;
  g1(140,29)=(-(y(102)*params(21)*getPowerDeriv(y(29),T1318,1)));
  g1(140,101)=T3;
  g1(140,102)=(-T1320);
  g1(140,126)=1;
  g1(141,76)=(-(y(115)*getPowerDeriv(y(76),T1318,1)/params(21)));
  g1(141,115)=(-(y(76)^T1318/params(21)));
  g1(141,116)=T3;
  g1(141,127)=1;
  g1(142,23)=(-(y(34)*y(46)+y(34)*y(44)));
  g1(142,34)=(-(y(46)*(1-(1-y(23)))+y(44)*(-(1-y(23)))));
  g1(142,35)=(-y(44));
  g1(142,44)=(-(y(35)-y(34)*(1-y(23))));
  g1(142,46)=(-(y(34)-y(34)*(1-y(23))));
  g1(142,140)=1;
  g1(143,24)=(-(y(35)*y(45)+y(35)*y(47)));
  g1(143,34)=(-y(47));
  g1(143,35)=(-(y(47)*(-(1-y(24)))+y(45)*(1-(1-y(24)))));
  g1(143,45)=(-(y(35)-y(35)*(1-y(24))));
  g1(143,47)=(-(y(34)-y(35)*(1-y(24))));
  g1(143,142)=1;
  g1(144,70)=(-(y(81)*y(93)+y(81)*y(91)));
  g1(144,81)=(-(y(93)*(1-(1-y(70)))+y(91)*(-(1-y(70)))));
  g1(144,82)=(-y(91));
  g1(144,91)=(-(y(82)-y(81)*(1-y(70))));
  g1(144,93)=(-(y(81)-y(81)*(1-y(70))));
  g1(144,141)=1;
  g1(145,71)=(-(y(82)*y(92)+y(82)*y(94)));
  g1(145,81)=(-y(94));
  g1(145,82)=(-(y(94)*(-(1-y(71)))+y(92)*(1-(1-y(71)))));
  g1(145,92)=(-(y(82)-y(82)*(1-y(71))));
  g1(145,94)=(-(y(81)-y(82)*(1-y(71))));
  g1(145,143)=1;
  g1(146,21)=(-T2433);
  g1(146,22)=T2467;
  g1(146,145)=1;
  g1(147,119)=T3;
  g1(147,146)=1;
  g1(148,106)=T3;
  g1(148,147)=1;
  g1(149,21)=(-T2433);
  g1(149,22)=T2467;
  g1(149,144)=1;
  g1(150,25)=(-(T650*T618*T2539));
  g1(150,35)=(-(T618*T622*getPowerDeriv(y(35),T451,1)));
  g1(150,148)=1;
  g1(151,29)=T2629;
  g1(151,102)=(-T430);
  g1(151,104)=(-(y(102)*T424*T427*getPowerDeriv(y(104),params(3),1)));
  g1(151,123)=T3955;
  g1(151,149)=1;
  g1(152,9)=1;
  g1(152,34)=(-((-y(36))/(y(34)*y(34))));
  g1(152,36)=(-(1/y(34)));
  g1(152,150)=1;
  g1(153,132)=T3;
  g1(153,134)=1;
  g1(153,151)=1;
  g1(154,8)=(-(1/y(13)));
  g1(154,13)=(-((-y(8))/(y(13)*y(13))));
  g1(154,152)=1;
  g1(155,155)=1;
  g1(156,156)=1;
  g1(157,34)=(-(y(156)-1));
  g1(157,35)=(-(1-y(156)));
  g1(157,156)=(-(y(34)-y(35)));
  g1(157,157)=1;
  g1(158,46)=(-y(156));
  g1(158,47)=(-(1-y(156)));
  g1(158,156)=(-(y(46)-y(47)));
  g1(158,158)=1;
  g1(159,34)=(-(y(158)-1));
  g1(159,35)=(-(1-y(158)));
  g1(159,158)=(-(y(34)-y(35)));
  g1(159,159)=1;
  g1(160,158)=(-(y(241)-y(242)));
  g1(160,160)=1;
  g1(160,241)=(-y(158));
  g1(160,242)=(-(1-y(158)));
  g1(161,34)=1;
  g1(161,160)=(-(y(243)-y(244)));
  g1(161,161)=1;
  g1(161,243)=(-y(160));
  g1(161,244)=(-(1-y(160)));
  g1(162,160)=(-(y(245)-y(246)));
  g1(162,162)=1;
  g1(162,245)=(-y(160));
  g1(162,246)=(-(1-y(160)));
  g1(163,34)=1;
  g1(163,162)=(-(y(247)-y(248)));
  g1(163,163)=1;
  g1(163,247)=(-y(162));
  g1(163,248)=(-(1-y(162)));
  g1(164,162)=(-(y(249)-y(250)));
  g1(164,164)=1;
  g1(164,249)=(-y(162));
  g1(164,250)=(-(1-y(162)));
  g1(165,34)=1;
  g1(165,164)=(-(y(251)-y(252)));
  g1(165,165)=1;
  g1(165,251)=(-y(164));
  g1(165,252)=(-(1-y(164)));
  g1(166,164)=(-(y(253)-y(254)));
  g1(166,166)=1;
  g1(166,253)=(-y(164));
  g1(166,254)=(-(1-y(164)));
  g1(167,34)=1;
  g1(167,166)=(-(y(255)-y(256)));
  g1(167,167)=1;
  g1(167,255)=(-y(166));
  g1(167,256)=(-(1-y(166)));
  g1(168,166)=(-(y(257)-y(258)));
  g1(168,168)=1;
  g1(168,257)=(-y(166));
  g1(168,258)=(-(1-y(166)));
  g1(169,34)=1;
  g1(169,168)=(-(y(259)-y(260)));
  g1(169,169)=1;
  g1(169,259)=(-y(168));
  g1(169,260)=(-(1-y(168)));
  g1(170,168)=(-(y(261)-y(262)));
  g1(170,170)=1;
  g1(170,261)=(-y(168));
  g1(170,262)=(-(1-y(168)));
  g1(171,34)=1;
  g1(171,170)=(-(y(263)-y(264)));
  g1(171,171)=1;
  g1(171,263)=(-y(170));
  g1(171,264)=(-(1-y(170)));
  g1(172,170)=(-(y(265)-y(266)));
  g1(172,172)=1;
  g1(172,265)=(-y(170));
  g1(172,266)=(-(1-y(170)));
  g1(173,34)=1;
  g1(173,172)=(-(y(267)-y(268)));
  g1(173,173)=1;
  g1(173,267)=(-y(172));
  g1(173,268)=(-(1-y(172)));
  g1(174,172)=(-(y(269)-y(270)));
  g1(174,174)=1;
  g1(174,269)=(-y(172));
  g1(174,270)=(-(1-y(172)));
  g1(175,34)=1;
  g1(175,174)=(-(y(271)-y(272)));
  g1(175,175)=1;
  g1(175,271)=(-y(174));
  g1(175,272)=(-(1-y(174)));
  g1(176,174)=(-(y(273)-y(274)));
  g1(176,176)=1;
  g1(176,273)=(-y(174));
  g1(176,274)=(-(1-y(174)));
  g1(177,34)=1;
  g1(177,176)=(-(y(275)-y(276)));
  g1(177,177)=1;
  g1(177,275)=(-y(176));
  g1(177,276)=(-(1-y(176)));
  g1(178,176)=(-(y(277)-y(278)));
  g1(178,178)=1;
  g1(178,277)=(-y(176));
  g1(178,278)=(-(1-y(176)));
  g1(179,34)=1;
  g1(179,178)=(-(y(279)-y(280)));
  g1(179,179)=1;
  g1(179,279)=(-y(178));
  g1(179,280)=(-(1-y(178)));
  g1(180,178)=(-(y(281)-y(282)));
  g1(180,180)=1;
  g1(180,281)=(-y(178));
  g1(180,282)=(-(1-y(178)));
  g1(181,34)=1;
  g1(181,180)=(-(y(283)-y(284)));
  g1(181,181)=1;
  g1(181,283)=(-y(180));
  g1(181,284)=(-(1-y(180)));
  g1(182,180)=(-(y(285)-y(286)));
  g1(182,182)=1;
  g1(182,285)=(-y(180));
  g1(182,286)=(-(1-y(180)));
  g1(183,34)=1;
  g1(183,182)=(-(y(287)-y(288)));
  g1(183,183)=1;
  g1(183,287)=(-y(182));
  g1(183,288)=(-(1-y(182)));
  g1(184,182)=(-(y(289)-y(290)));
  g1(184,184)=1;
  g1(184,289)=(-y(182));
  g1(184,290)=(-(1-y(182)));
  g1(185,34)=1;
  g1(185,184)=(-(y(291)-y(292)));
  g1(185,185)=1;
  g1(185,291)=(-y(184));
  g1(185,292)=(-(1-y(184)));
  g1(186,184)=(-(y(293)-y(294)));
  g1(186,186)=1;
  g1(186,293)=(-y(184));
  g1(186,294)=(-(1-y(184)));
  g1(187,34)=1;
  g1(187,186)=(-(y(295)-y(296)));
  g1(187,187)=1;
  g1(187,295)=(-y(186));
  g1(187,296)=(-(1-y(186)));
  g1(188,186)=(-(y(297)-y(298)));
  g1(188,188)=1;
  g1(188,297)=(-y(186));
  g1(188,298)=(-(1-y(186)));
  g1(189,34)=1;
  g1(189,188)=(-(y(299)-y(300)));
  g1(189,189)=1;
  g1(189,299)=(-y(188));
  g1(189,300)=(-(1-y(188)));
  g1(190,188)=(-(y(301)-y(302)));
  g1(190,190)=1;
  g1(190,301)=(-y(188));
  g1(190,302)=(-(1-y(188)));
  g1(191,34)=1;
  g1(191,190)=(-(y(303)-y(304)));
  g1(191,191)=1;
  g1(191,303)=(-y(190));
  g1(191,304)=(-(1-y(190)));
  g1(192,190)=(-(y(305)-y(306)));
  g1(192,192)=1;
  g1(192,305)=(-y(190));
  g1(192,306)=(-(1-y(190)));
  g1(193,34)=1;
  g1(193,192)=(-(y(307)-y(308)));
  g1(193,193)=1;
  g1(193,307)=(-y(192));
  g1(193,308)=(-(1-y(192)));
  g1(194,192)=(-(y(309)-y(310)));
  g1(194,194)=1;
  g1(194,309)=(-y(192));
  g1(194,310)=(-(1-y(192)));
  g1(195,34)=1;
  g1(195,194)=(-(y(311)-y(312)));
  g1(195,195)=1;
  g1(195,311)=(-y(194));
  g1(195,312)=(-(1-y(194)));
  g1(196,194)=(-(y(313)-y(314)));
  g1(196,196)=1;
  g1(196,313)=(-y(194));
  g1(196,314)=(-(1-y(194)));
  g1(197,34)=1;
  g1(197,196)=(-(y(315)-y(316)));
  g1(197,197)=1;
  g1(197,315)=(-y(196));
  g1(197,316)=(-(1-y(196)));
  g1(198,198)=1;
  g1(199,199)=1;
  g1(200,34)=(-(1-y(199)));
  g1(200,35)=(-(y(199)-1));
  g1(200,199)=(-(y(35)-y(34)));
  g1(200,200)=1;
  g1(201,44)=(-(1-y(199)));
  g1(201,45)=(-y(199));
  g1(201,199)=(-(y(45)-y(44)));
  g1(201,201)=1;
  g1(202,34)=(-(1-y(201)));
  g1(202,35)=(-(y(201)-1));
  g1(202,201)=(-(y(35)-y(34)));
  g1(202,202)=1;
  g1(203,201)=(-(y(317)-y(318)));
  g1(203,203)=1;
  g1(203,317)=(-y(201));
  g1(203,318)=(-(1-y(201)));
  g1(204,35)=1;
  g1(204,203)=(-(y(244)-y(243)));
  g1(204,204)=1;
  g1(204,243)=(-(1-y(203)));
  g1(204,244)=(-y(203));
  g1(205,203)=(-(y(319)-y(320)));
  g1(205,205)=1;
  g1(205,319)=(-y(203));
  g1(205,320)=(-(1-y(203)));
  g1(206,35)=1;
  g1(206,205)=(-(y(248)-y(247)));
  g1(206,206)=1;
  g1(206,247)=(-(1-y(205)));
  g1(206,248)=(-y(205));
  g1(207,205)=(-(y(321)-y(322)));
  g1(207,207)=1;
  g1(207,321)=(-y(205));
  g1(207,322)=(-(1-y(205)));
  g1(208,35)=1;
  g1(208,207)=(-(y(252)-y(251)));
  g1(208,208)=1;
  g1(208,251)=(-(1-y(207)));
  g1(208,252)=(-y(207));
  g1(209,207)=(-(y(323)-y(324)));
  g1(209,209)=1;
  g1(209,323)=(-y(207));
  g1(209,324)=(-(1-y(207)));
  g1(210,35)=1;
  g1(210,209)=(-(y(256)-y(255)));
  g1(210,210)=1;
  g1(210,255)=(-(1-y(209)));
  g1(210,256)=(-y(209));
  g1(211,209)=(-(y(325)-y(326)));
  g1(211,211)=1;
  g1(211,325)=(-y(209));
  g1(211,326)=(-(1-y(209)));
  g1(212,35)=1;
  g1(212,211)=(-(y(260)-y(259)));
  g1(212,212)=1;
  g1(212,259)=(-(1-y(211)));
  g1(212,260)=(-y(211));
  g1(213,211)=(-(y(327)-y(328)));
  g1(213,213)=1;
  g1(213,327)=(-y(211));
  g1(213,328)=(-(1-y(211)));
  g1(214,35)=1;
  g1(214,213)=(-(y(264)-y(263)));
  g1(214,214)=1;
  g1(214,263)=(-(1-y(213)));
  g1(214,264)=(-y(213));
  g1(215,213)=(-(y(329)-y(330)));
  g1(215,215)=1;
  g1(215,329)=(-y(213));
  g1(215,330)=(-(1-y(213)));
  g1(216,35)=1;
  g1(216,215)=(-(y(268)-y(267)));
  g1(216,216)=1;
  g1(216,267)=(-(1-y(215)));
  g1(216,268)=(-y(215));
  g1(217,215)=(-(y(331)-y(332)));
  g1(217,217)=1;
  g1(217,331)=(-y(215));
  g1(217,332)=(-(1-y(215)));
  g1(218,35)=1;
  g1(218,217)=(-(y(272)-y(271)));
  g1(218,218)=1;
  g1(218,271)=(-(1-y(217)));
  g1(218,272)=(-y(217));
  g1(219,217)=(-(y(333)-y(334)));
  g1(219,219)=1;
  g1(219,333)=(-y(217));
  g1(219,334)=(-(1-y(217)));
  g1(220,35)=1;
  g1(220,219)=(-(y(276)-y(275)));
  g1(220,220)=1;
  g1(220,275)=(-(1-y(219)));
  g1(220,276)=(-y(219));
  g1(221,219)=(-(y(335)-y(336)));
  g1(221,221)=1;
  g1(221,335)=(-y(219));
  g1(221,336)=(-(1-y(219)));
  g1(222,35)=1;
  g1(222,221)=(-(y(280)-y(279)));
  g1(222,222)=1;
  g1(222,279)=(-(1-y(221)));
  g1(222,280)=(-y(221));
  g1(223,221)=(-(y(337)-y(338)));
  g1(223,223)=1;
  g1(223,337)=(-y(221));
  g1(223,338)=(-(1-y(221)));
  g1(224,35)=1;
  g1(224,223)=(-(y(284)-y(283)));
  g1(224,224)=1;
  g1(224,283)=(-(1-y(223)));
  g1(224,284)=(-y(223));
  g1(225,223)=(-(y(339)-y(340)));
  g1(225,225)=1;
  g1(225,339)=(-y(223));
  g1(225,340)=(-(1-y(223)));
  g1(226,35)=1;
  g1(226,225)=(-(y(288)-y(287)));
  g1(226,226)=1;
  g1(226,287)=(-(1-y(225)));
  g1(226,288)=(-y(225));
  g1(227,225)=(-(y(341)-y(342)));
  g1(227,227)=1;
  g1(227,341)=(-y(225));
  g1(227,342)=(-(1-y(225)));
  g1(228,35)=1;
  g1(228,227)=(-(y(292)-y(291)));
  g1(228,228)=1;
  g1(228,291)=(-(1-y(227)));
  g1(228,292)=(-y(227));
  g1(229,227)=(-(y(343)-y(344)));
  g1(229,229)=1;
  g1(229,343)=(-y(227));
  g1(229,344)=(-(1-y(227)));
  g1(230,35)=1;
  g1(230,229)=(-(y(296)-y(295)));
  g1(230,230)=1;
  g1(230,295)=(-(1-y(229)));
  g1(230,296)=(-y(229));
  g1(231,229)=(-(y(345)-y(346)));
  g1(231,231)=1;
  g1(231,345)=(-y(229));
  g1(231,346)=(-(1-y(229)));
  g1(232,35)=1;
  g1(232,231)=(-(y(300)-y(299)));
  g1(232,232)=1;
  g1(232,299)=(-(1-y(231)));
  g1(232,300)=(-y(231));
  g1(233,231)=(-(y(347)-y(348)));
  g1(233,233)=1;
  g1(233,347)=(-y(231));
  g1(233,348)=(-(1-y(231)));
  g1(234,35)=1;
  g1(234,233)=(-(y(304)-y(303)));
  g1(234,234)=1;
  g1(234,303)=(-(1-y(233)));
  g1(234,304)=(-y(233));
  g1(235,233)=(-(y(349)-y(350)));
  g1(235,235)=1;
  g1(235,349)=(-y(233));
  g1(235,350)=(-(1-y(233)));
  g1(236,35)=1;
  g1(236,235)=(-(y(308)-y(307)));
  g1(236,236)=1;
  g1(236,307)=(-(1-y(235)));
  g1(236,308)=(-y(235));
  g1(237,235)=(-(y(351)-y(352)));
  g1(237,237)=1;
  g1(237,351)=(-y(235));
  g1(237,352)=(-(1-y(235)));
  g1(238,35)=1;
  g1(238,237)=(-(y(312)-y(311)));
  g1(238,238)=1;
  g1(238,311)=(-(1-y(237)));
  g1(238,312)=(-y(237));
  g1(239,237)=(-(y(353)-y(354)));
  g1(239,239)=1;
  g1(239,353)=(-y(237));
  g1(239,354)=(-(1-y(237)));
  g1(240,35)=1;
  g1(240,239)=(-(y(316)-y(315)));
  g1(240,240)=1;
  g1(240,315)=(-(1-y(239)));
  g1(240,316)=(-y(239));
  g1(241,46)=T3;
  g1(241,241)=1;
  g1(242,47)=T3;
  g1(242,242)=1;
  g1(243,34)=T3;
  g1(243,243)=1;
  g1(244,35)=T3;
  g1(244,244)=1;
  g1(245,241)=T3;
  g1(245,245)=1;
  g1(246,242)=T3;
  g1(246,246)=1;
  g1(247,243)=T3;
  g1(247,247)=1;
  g1(248,244)=T3;
  g1(248,248)=1;
  g1(249,245)=T3;
  g1(249,249)=1;
  g1(250,246)=T3;
  g1(250,250)=1;
  g1(251,247)=T3;
  g1(251,251)=1;
  g1(252,248)=T3;
  g1(252,252)=1;
  g1(253,249)=T3;
  g1(253,253)=1;
  g1(254,250)=T3;
  g1(254,254)=1;
  g1(255,251)=T3;
  g1(255,255)=1;
  g1(256,252)=T3;
  g1(256,256)=1;
  g1(257,253)=T3;
  g1(257,257)=1;
  g1(258,254)=T3;
  g1(258,258)=1;
  g1(259,255)=T3;
  g1(259,259)=1;
  g1(260,256)=T3;
  g1(260,260)=1;
  g1(261,257)=T3;
  g1(261,261)=1;
  g1(262,258)=T3;
  g1(262,262)=1;
  g1(263,259)=T3;
  g1(263,263)=1;
  g1(264,260)=T3;
  g1(264,264)=1;
  g1(265,261)=T3;
  g1(265,265)=1;
  g1(266,262)=T3;
  g1(266,266)=1;
  g1(267,263)=T3;
  g1(267,267)=1;
  g1(268,264)=T3;
  g1(268,268)=1;
  g1(269,265)=T3;
  g1(269,269)=1;
  g1(270,266)=T3;
  g1(270,270)=1;
  g1(271,267)=T3;
  g1(271,271)=1;
  g1(272,268)=T3;
  g1(272,272)=1;
  g1(273,269)=T3;
  g1(273,273)=1;
  g1(274,270)=T3;
  g1(274,274)=1;
  g1(275,271)=T3;
  g1(275,275)=1;
  g1(276,272)=T3;
  g1(276,276)=1;
  g1(277,273)=T3;
  g1(277,277)=1;
  g1(278,274)=T3;
  g1(278,278)=1;
  g1(279,275)=T3;
  g1(279,279)=1;
  g1(280,276)=T3;
  g1(280,280)=1;
  g1(281,277)=T3;
  g1(281,281)=1;
  g1(282,278)=T3;
  g1(282,282)=1;
  g1(283,279)=T3;
  g1(283,283)=1;
  g1(284,280)=T3;
  g1(284,284)=1;
  g1(285,281)=T3;
  g1(285,285)=1;
  g1(286,282)=T3;
  g1(286,286)=1;
  g1(287,283)=T3;
  g1(287,287)=1;
  g1(288,284)=T3;
  g1(288,288)=1;
  g1(289,285)=T3;
  g1(289,289)=1;
  g1(290,286)=T3;
  g1(290,290)=1;
  g1(291,287)=T3;
  g1(291,291)=1;
  g1(292,288)=T3;
  g1(292,292)=1;
  g1(293,289)=T3;
  g1(293,293)=1;
  g1(294,290)=T3;
  g1(294,294)=1;
  g1(295,291)=T3;
  g1(295,295)=1;
  g1(296,292)=T3;
  g1(296,296)=1;
  g1(297,293)=T3;
  g1(297,297)=1;
  g1(298,294)=T3;
  g1(298,298)=1;
  g1(299,295)=T3;
  g1(299,299)=1;
  g1(300,296)=T3;
  g1(300,300)=1;
  g1(301,297)=T3;
  g1(301,301)=1;
  g1(302,298)=T3;
  g1(302,302)=1;
  g1(303,299)=T3;
  g1(303,303)=1;
  g1(304,300)=T3;
  g1(304,304)=1;
  g1(305,301)=T3;
  g1(305,305)=1;
  g1(306,302)=T3;
  g1(306,306)=1;
  g1(307,303)=T3;
  g1(307,307)=1;
  g1(308,304)=T3;
  g1(308,308)=1;
  g1(309,305)=T3;
  g1(309,309)=1;
  g1(310,306)=T3;
  g1(310,310)=1;
  g1(311,307)=T3;
  g1(311,311)=1;
  g1(312,308)=T3;
  g1(312,312)=1;
  g1(313,309)=T3;
  g1(313,313)=1;
  g1(314,310)=T3;
  g1(314,314)=1;
  g1(315,311)=T3;
  g1(315,315)=1;
  g1(316,312)=T3;
  g1(316,316)=1;
  g1(317,45)=T3;
  g1(317,317)=1;
  g1(318,44)=T3;
  g1(318,318)=1;
  g1(319,317)=T3;
  g1(319,319)=1;
  g1(320,318)=T3;
  g1(320,320)=1;
  g1(321,319)=T3;
  g1(321,321)=1;
  g1(322,320)=T3;
  g1(322,322)=1;
  g1(323,321)=T3;
  g1(323,323)=1;
  g1(324,322)=T3;
  g1(324,324)=1;
  g1(325,323)=T3;
  g1(325,325)=1;
  g1(326,324)=T3;
  g1(326,326)=1;
  g1(327,325)=T3;
  g1(327,327)=1;
  g1(328,326)=T3;
  g1(328,328)=1;
  g1(329,327)=T3;
  g1(329,329)=1;
  g1(330,328)=T3;
  g1(330,330)=1;
  g1(331,329)=T3;
  g1(331,331)=1;
  g1(332,330)=T3;
  g1(332,332)=1;
  g1(333,331)=T3;
  g1(333,333)=1;
  g1(334,332)=T3;
  g1(334,334)=1;
  g1(335,333)=T3;
  g1(335,335)=1;
  g1(336,334)=T3;
  g1(336,336)=1;
  g1(337,335)=T3;
  g1(337,337)=1;
  g1(338,336)=T3;
  g1(338,338)=1;
  g1(339,337)=T3;
  g1(339,339)=1;
  g1(340,338)=T3;
  g1(340,340)=1;
  g1(341,339)=T3;
  g1(341,341)=1;
  g1(342,340)=T3;
  g1(342,342)=1;
  g1(343,341)=T3;
  g1(343,343)=1;
  g1(344,342)=T3;
  g1(344,344)=1;
  g1(345,343)=T3;
  g1(345,345)=1;
  g1(346,344)=T3;
  g1(346,346)=1;
  g1(347,345)=T3;
  g1(347,347)=1;
  g1(348,346)=T3;
  g1(348,348)=1;
  g1(349,347)=T3;
  g1(349,349)=1;
  g1(350,348)=T3;
  g1(350,350)=1;
  g1(351,349)=T3;
  g1(351,351)=1;
  g1(352,350)=T3;
  g1(352,352)=1;
  g1(353,351)=T3;
  g1(353,353)=1;
  g1(354,352)=T3;
  g1(354,354)=1;
  g1(355,355)=1;
  g1(356,356)=1;
  g1(357,357)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],357,127449);
end
end
